@@ -5,23 +5,31 @@ OC.L10N.register(
     "You left the call" : "لقد قمت بمغادرة المكالمة",
     "Click the button below to join." : "اضغط على الزر للانضمام.",
     "Conversation not found" : "المحادثة غير موجودة",
+    "Everyone" : "الجميع",
+    "Save changes" : "حفظ التعديلات",
     "None" : "لا شيء",
     "User" : "المستخدم",
-    "Everyone" : "الجميع",
     "Disabled" : "معطّل",
     "Users" : "المستخدمين:",
+    "Beta" : "تجريبي",
+    "Name" : "الاسم",
+    "Command" : "الأمر",
+    "General settings" : "الإعدادات العامة",
+    "All messages" : "كافة الرسائل",
+    "Saved" : "تم الإحتفاظ به",
+    "Add a new server" : "إضافة خادم جديد",
     "Test this server" : "جرّب هذا الخادم",
     "Copy link" : "انسخ الرابط",
+    "Mute audio" : "كتم الصوت",
     "Disable video" : "تعطيل الفيديو",
     "Favorite" : "المفضلة",
-    "All messages" : "كافة الرسائل",
     "Leave conversation" : "غادر المحادثة",
     "Delete conversation" : "احذف المحادثة",
     "Remove from favorites" : "إزالتها مِن المفضلة",
     "Add to favorites" : "أضفه إلى المفضلة",
     "Contacts" : "المُراسِلون",
-    "Groups" : "الفِرَق",
     "Loading" : "Loading",
+    "Groups" : "الفِرَق",
     "Error" : "خطأ",
     "Password protect" : "حماية كلمة السر",
     "Back" : "العودة",
@@ -30,46 +38,40 @@ OC.L10N.register(
     "Reply" : "رد",
     "Today" : "اليوم",
     "Yesterday" : "البارحة",
+    "Send message" : "أرسل رسالة",
     "No results" : "دون أية نتيجة",
     "Participants" : "المشاركون",
+    "Chat" : "الدردشة",
+    "Projects" : "المشاريع",
+    "Settings" : "الإعدادات",
+    "Edit" : "تعديل",
+    "Dismiss" : "تراجع",
     "Rename conversation" : "إعادة تسمية المحادثة",
-    "Guests" : "الضيوف",
     "Share link" : "مشاركة الرابط",
     "Password protection" : "الحماية بكلمة السر",
     "Enter a password" : "إدخِل كلمة سرية",
-    "Chat" : "الدردشة",
-    "Projects" : "المشاريع",
-    "Edit" : "تعديل",
-    "Save changes" : "حفظ التعديلات",
-    "Beta" : "تجريبي",
-    "Name" : "الاسم",
-    "Command" : "الأمر",
-    "General settings" : "الإعدادات العامة",
-    "Saved" : "تم الإحتفاظ به",
-    "Add a new server" : "إضافة خادم جديد",
-    "Password required" : "كلمة السر مطلوبة",
-    "Password" : "الكلمة السرية",
-    "Cancel" : "إلغاء",
+    "Grid view" : "عرض شبكي",
     "The password is wrong. Try again." : "كلمة المرور خاطئة. حاول مرة أخرى.",
+    "Password" : "الكلمة السرية",
+    "Join conversations at any time, anywhere, on any device." : "انضم إلى المحادثات في أي وقت و من أي مكان و عبر أي جهاز",
     "Android app" : "تطبيق الأندرويد",
     "iOS app" : "تطبيق آي أواس",
-    "New public conversation" : "محادثة عمومية جديدة",
     "Copy" : "أنسخ",
     "Copied!" : "تم نسخه !",
     "Not supported!" : "غير مدعوم!",
     "Press ⌘-C to copy." : "إضغط ⌘-C للنسخ",
     "Press Ctrl-C to copy." : "إضغط Ctrl-C للنسخ.",
-    "Start a conversation" : "ابدأ محادثة",
-    "Share" : "شارك",
+    "Password required" : "كلمة السر مطلوبة",
+    "Cancel" : "إلغاء",
+    "Guests" : "الضيوف",
     "Change password" : "تعديل الكلمة السرية",
     "Set password" : "تعيين كلمة سرية",
     "Rename" : "إعادة التسمية",
     "You" : "أنت",
     "Send" : "أرسل",
+    "Share" : "شارك",
     "Error while sharing" : "حصل خطأ عند عملية المشاركة",
-    "Mute audio" : "كتم الصوت",
     "Favorited" : "المفضلة",
-    ", " : ",",
-    "Join now" : "انضم الآن"
+    "Join conversations at any time, any where, on any device." : "انضم إلى المحادثات في أي وقت و من أي مكان و عبر أي جهاز"
 },
 "nplurals=6; plural=n==0 ? 0 : n==1 ? 1 : n==2 ? 2 : n%100>=3 && n%100<=10 ? 3 : n%100>=11 && n%100<=99 ? 4 : 5;");
