@@ -3,28 +3,40 @@ OC.L10N.register(
     {
     "Guest" : "Гост",
     "Invalid date, date format must be YYYY-MM-DD" : "Невалидна дата, форматът е различен от ГГГГ-ММ-ДД",
+    "Limit to groups" : "Ограничен достъп",
+    "Everyone" : "Всички",
+    "Save changes" : "Запиши промените",
+    "Saving …" : "Записване …",
+    "Saved!" : "Записано!",
     "None" : "Без",
     "User" : "Потребител",
-    "Everyone" : "Всички",
     "Disabled" : "Изключено",
     "Users" : "Потребители",
-    "TURN server URL" : "URL на TURN сървъра",
+    "Commands" : "Команди",
+    "Beta" : "Бета",
+    "Name" : "Име",
+    "General settings" : "Общи настройки",
     "Validate SSL certificate" : "Проверка на SSL сертификата",
+    "Saved" : "Запазено",
     "STUN server URL" : "URL на STUN сървъра",
+    "STUN servers" : "STUN сървъри",
+    "TURN server URL" : "URL на TURN сървъра",
     "TURN server protocols" : "Протоколи на TURN сървър",
     "UDP and TCP" : "UDP и TCP",
     "UDP only" : "само UDP",
     "TCP only" : "само TCP",
     "Copy link" : "Копирай връзката",
+    "Mute audio" : "Спиране на звука",
     "Disable video" : "Изключване на видеото",
     "Enable video" : "Включи видео",
     "Favorite" : "Любима",
     "Remove from favorites" : "Премахни от любимите",
     "Add to favorites" : "Добави към любимите",
     "Contacts" : "Контакти",
+    "Loading" : "Зареждане",
     "Groups" : "Групи",
     "Circles" : "Обкръжения",
-    "Loading" : "Зареждане",
+    "Invalid path selected" : "Предоставен е невалиден път до файл.",
     "Error" : "Грешка",
     "Password protect" : "Защита с парола",
     "Back" : "Назад",
@@ -32,57 +44,49 @@ OC.L10N.register(
     "Reply" : "Отговори",
     "Today" : "Днес",
     "Yesterday" : "Вчера",
-    "Invalid path selected" : "Предоставен е невалиден път до файл.",
+    "Send message" : "Изпрати съобщение",
     "guest" : "гост",
-    "No results" : "Няма резултати",
+    "Remove participant" : "Премахване на участник",
     "Searching …" : "Търсене ...",
-    "Guests" : "Гости",
+    "No results" : "Няма резултати",
+    "Participants" : "Участници",
+    "Chat" : "Съобщения",
+    "Settings" : "Настройки",
+    "Edit" : "Променяне",
+    "Dismiss" : "Отхвърляне",
     "Share link" : "Сподели връзка",
     "Password protection" : "Password protection",
     "Enter a password" : "Въведете парола",
-    "Chat" : "Съобщения",
-    "Edit" : "Променяне",
-    "Limit to groups" : "Ограничен достъп",
-    "Save changes" : "Запиши промените",
-    "Saving …" : "Записване …",
-    "Saved!" : "Записано!",
-    "Commands" : "Команди",
-    "Beta" : "Бета",
-    "Name" : "Име",
-    "General settings" : "Общи настройки",
-    "Saved" : "Запазено",
-    "STUN servers" : "STUN сървъри",
-    "Password required" : "Паролата е задължителна",
-    "Password" : "Парола",
-    "Cancel" : "Отказ",
-    "Submit" : "Изпращане",
+    "Grid view" : "Решетъчен изглед",
     "Access to microphone & camera is only possible with HTTPS" : "Достъпът до микрофона и камерата е възможен само при HTTPS",
     "Access to microphone & camera was denied" : "Достъпът до микрофона и камерата е отказан",
     "Please use a different browser like Firefox or Chrome" : "Моля, използвайте друг браузър като Firefox или Chrome",
     "Error while accessing microphone & camera" : "Грешка при достъп до микрофон и камера",
     "The password is wrong. Try again." : "Паролата е грешна. Опитайте отново.",
+    "Password" : "Парола",
     "TURN server" : "TURN сървър",
     "The TURN server is used to proxy the traffic from participants behind a firewall." : "TURN сървърът се използва като прокси сървър за трафика, идващ от участници стоящи зад защитна стена.",
     "Android app" : "Android приложение",
     "iOS app" : "iOS приложениер",
-    "Delete server" : "Изтриване на сървъра",
-    "Add new server" : "Добавете нов сървър",
     "Copy" : "Копиране",
     "Copied!" : "Копирано!",
     "Not supported!" : "Не се поддържа!",
     "Press ⌘-C to copy." : "За копиране натиснете ⌘-C",
     "Press Ctrl-C to copy." : "За копиране натиснете Ctrl-C",
-    "Share" : "Споделяне",
+    "Password required" : "Паролата е задължителна",
+    "Cancel" : "Отказ",
+    "Submit" : "Изпращане",
+    "Guests" : "Гости",
+    "Webinar" : "Уебинар",
     "Change password" : "Промени паролата",
     "Set password" : "Задайте парола",
     "Rename" : "Преименуване",
     "Link copied!" : "Връзката е копирана!",
     "You" : "Ти",
     "Send" : "Изпрати",
+    "Share" : "Споделяне",
     "Error while sharing" : "Грешка при споделяне",
-    "Mute audio" : "Спиране на звука",
     "Share screen" : "Споделяне на екран",
-    "Favorited" : "Отбелязано в любими",
-    ", " : ", "
+    "Favorited" : "Отбелязано в любими"
 },
 "nplurals=2; plural=(n != 1);");
