@@ -5,13 +5,15 @@ OC.L10N.register(
     "User" : "User",
     "Disabled" : "Analluogwyd",
     "Users" : "Defnyddwyr",
+    "Name" : "Enw",
+    "Saved" : "Wedi'u cadw",
     "Copy link" : "Copïo dolen",
     "Favorite" : "Ffefryn",
     "Remove from favorites" : "Remove from favorites",
     "Add to favorites" : "Add to favorites",
     "Contacts" : "Cysylltiadau",
-    "Groups" : "Grwpiau",
     "Loading" : "Llwytho",
+    "Groups" : "Grwpiau",
     "Error" : "Gwall",
     "Password protect" : "Diogelu cyfrinair",
     "Back" : "Nôl",
@@ -19,18 +21,18 @@ OC.L10N.register(
     "Today" : "Heddiw",
     "Yesterday" : "Ddoe",
     "No results" : "Dim canlyniadau",
+    "Settings" : "Gosodiadau",
+    "Edit" : "Golygu",
     "Share link" : "Rhannu dolen",
     "Password protection" : "Password protection",
     "Enter a password" : "Enter a password",
-    "Edit" : "Golygu",
-    "Name" : "Enw",
-    "Saved" : "Wedi'u cadw",
+    "Grid view" : "Golwg grid",
     "Password" : "Cyfrinair",
-    "Cancel" : "Diddymu",
     "Copy" : "Copïo",
-    "Share" : "Rhannu",
+    "Cancel" : "Diddymu",
     "Rename" : "Ailenwi",
     "Send" : "Anfon",
+    "Share" : "Rhannu",
     "Error while sharing" : "Gwall wrth rannu"
 },
 "nplurals=4; plural=(n==1) ? 0 : (n==2) ? 1 : (n != 8 && n != 11) ? 2 : 3;");
