@@ -17,23 +17,35 @@ OC.L10N.register(
     "{user} wants to talk with you" : "{user} quiere hablar contigo",
     "A group call has started in {call}" : "Una llamada en grupo ha iniciado en {call}",
     "Invalid date, date format must be YYYY-MM-DD" : "La fecha es inválida, por favor sigue el formato AAAA-MM-DD",
+    "Leave call" : "Dejar la llamada",
+    "Limit to groups" : "Limitar a grupos",
+    "Everyone" : "Todos",
+    "Save changes" : "Guardar cambios",
+    "Saved!" : "¡Guardado!",
     "None" : "Ninguno",
     "User" : "Ususario",
-    "Everyone" : "Todos",
     "Disabled" : "Deshabilitado",
     "Users" : "Ususarios",
+    "Name" : "Nombre",
+    "General settings" : "Configuraciones generales",
     "Validate SSL certificate" : "Validar certificado SSL",
+    "Saved" : "Guardado",
+    "Shared secret" : "Secreto compartido",
+    "STUN servers" : "Servidores STUN",
+    "A STUN server is used to determine the public IP address of participants behind a router." : "Un servidor STUN se está usando para determinar la IP pública de los participantes que estén detrás de un ruteador. ",
     "TURN server protocols" : "Protocolos del servidor TURN",
     "UDP and TCP" : "UDP y TCP",
     "UDP only" : "UDP únicamente",
     "TCP only" : "TCP únicamente",
     "Copy link" : "Copiar liga",
-    "No other people in this call" : "No hay más personas en esta llamada",
     "Waiting for others to join the call …" : "Esperando a que los demás se unan a la llamada ...",
     "You can invite others in the participant tab of the sidebar" : "Puedes invitar a otras personas en la pestaña de participante del menú lateral",
     "Share this link to invite others!" : "¡Comparte esta liga para invitar a otras personas!",
     "Show your screen" : "Mostrar tu pantalla",
     "Stop screensharing" : "Dejar de compartir la pantalla",
+    "Mute audio" : "Silenciar audio",
+    "Disable video" : "Deshabilitar video",
+    "Enable video" : "Habilitar el video",
     "Screensharing options" : "Opciones de compartir pantalla",
     "Enable screensharing" : "Habilitar compartir pantalla",
     "Screensharing requires the page to be loaded through HTTPS." : "Compartir pantalla requiere que la página se cargue a través de HTTPS.",
@@ -43,21 +55,18 @@ OC.L10N.register(
     "An error occurred while starting screensharing." : "Se presentó un error al comenzar a compartir la pantalla. ",
     "Your screen" : "Tu pantalla",
     "Show screen" : "Mostrar pantalla",
-    "Disable video" : "Deshabilitar video",
-    "Enable video" : "Habilitar el video",
     "Favorite" : "Hacer favorito",
     "Remove from favorites" : "Eliminar de favoritos",
     "Add to favorites" : "Agregar a tus favoritos",
     "Contacts" : "Contactos",
+    "Loading" : "Cargando",
     "Groups" : "Grupos",
     "Circles" : "Círculos",
-    "Loading" : "Cargando",
     "Error" : "Error",
     "Password protect" : "Proteger con contraseña",
     "Back" : "Atrás",
     "Close" : "Cerrar",
     "Reply" : "Responder",
-    "[Unknown user name]" : "[Nombre de usuario desconocido]",
     "Today" : "Hoy",
     "Yesterday" : "Ayer",
     "moderator" : "moderador",
@@ -66,70 +75,55 @@ OC.L10N.register(
     "Remove participant" : "Eliminar participante",
     "No results" : "No hay resultados",
     "Participants" : "Participantes",
-    "Guests" : "Invitados",
+    "Chat" : "Chat",
+    "Settings" : "Configuraciones ",
+    "Edit" : "Editar",
+    "Dismiss" : "Descartar",
     "Share link" : "Compartir liga",
     "Password protection" : "Protección con contraseña",
     "Enter a password" : "Ingresa una contraseña",
-    "Chat" : "Chat",
-    "Edit" : "Editar",
-    "Leave call" : "Dejar la llamada",
-    "Limit to groups" : "Limitar a grupos",
-    "Save changes" : "Guardar cambios",
-    "Saved!" : "¡Guardado!",
-    "Name" : "Nombre",
-    "General settings" : "Configuraciones generales",
-    "Saved" : "Guardado",
-    "Shared secret" : "Secreto compartido",
-    "STUN servers" : "Servidores STUN",
-    "A STUN server is used to determine the public IP address of participants behind a router." : "Un servidor STUN se está usando para determinar la IP pública de los participantes que estén detrás de un ruteador. ",
-    "Please enter the password for this call" : "Por favor ingresa la contraseña para esta llamada",
-    "Password required" : "Contraseña requerida",
-    "Password" : "Contraseña",
-    "Cancel" : "Cancelar",
-    "Submit" : "Enviar",
+    "Grid view" : "Vista de cuadrícula",
     "Access to microphone & camera is only possible with HTTPS" : "El acceso al micrófono & cámara sólo es posible mediante HTTPS",
     "Access to microphone & camera was denied" : "El acceso al micrófono & cámara fue denegado",
     "WebRTC is not supported in your browser" : "WebRTC no está soportado en tu navegador",
     "Please use a different browser like Firefox or Chrome" : "Por favor usa un navegador diferente como Firefox o Chrome",
     "Error while accessing microphone & camera" : "Se pressentó un error al acceder al micrófono & cámara",
     "The password is wrong. Try again." : "La contraseña está equivoada. Por favor vuelve a intentarlo. ",
-    "An external signaling server can optionally be used for larger installations. Leave empty to use the internal signaling server." : "Un servidor externo de señalización puede ser, opcionalmente, utilizado para instalaciones más grandes. Déjalo vacío para usar el sevidor de señalización interno. ",
+    "Password" : "Contraseña",
     "TURN server" : "Servidor TURN",
     "The TURN server is used to proxy the traffic from participants behind a firewall." : "El servidor TURN se usa para concentrar el tráfico de participantes detras de un firewall. ",
+    "An external signaling server can optionally be used for larger installations. Leave empty to use the internal signaling server." : "Un servidor externo de señalización puede ser, opcionalmente, utilizado para instalaciones más grandes. Déjalo vacío para usar el sevidor de señalización interno. ",
     "Android app" : "Aplicación android",
     "iOS app" : "Aplicación iOS",
-    "Delete server" : "Borrar servidor",
-    "Add new server" : "Agregar un servidor nuevo ",
-    "TURN server shared secret" : "Secreto compartido del servidor TURN",
     "Copy" : "Copiar",
     "Copied!" : "¡Copiado!",
     "Not supported!" : "¡No soportado!",
     "Press ⌘-C to copy." : "Presiona ⌘-C para copiar.",
     "Press Ctrl-C to copy." : "Presiona Ctrl-C para copiar.",
-    "Share" : "Compartir",
+    "Please enter the password for this call" : "Por favor ingresa la contraseña para esta llamada",
+    "Password required" : "Contraseña requerida",
+    "Cancel" : "Cancelar",
+    "Submit" : "Enviar",
+    "Guests" : "Invitados",
     "Change password" : "Cambiar contraseña",
     "Set password" : "Establecer contraseña",
     "Rename" : "Renombrar",
     "You" : "Tú",
     "No messages yet, start the conversation!" : "Aún no hay mensajes. ¡!Inicia la conversación!",
     "Send" : "Enviar",
+    "Share" : "Compartir",
+    "[Unknown user name]" : "[Nombre de usuario desconocido]",
     "Error occurred while sending message" : "Se presentó un error al enviar el mensaje",
     "Error while sharing" : "Se presentó un error al compartir",
+    "No other people in this call" : "No hay más personas en esta llamada",
     "Waiting for {participantName} to join the call …" : "Esperando a que {participantName} se una a la llamada…",
     "WebRTC is not supported in your browser :-/" : "WebRTC no se encuentra soportado en tu navegador :-/",
     "Waiting for camera and microphone permissions" : "Aguardando los permisos para la cámara y micrófono",
     "Please, give your browser access to use your camera and microphone in order to use this app." : "Por favor da acceso a tu navegador para usar tu camara y micrófono poder usar esta aplicación. ",
-    "Mute audio" : "Silenciar audio",
     "Share screen" : "Compartir la pantalla",
     "Screensharing is not supported by your browser." : "Compartir pantalla no está soportado por tu navegador. ",
     "Favorited" : "Marcado como favorito",
     "{participantName}'s screen" : "Pantalla de {participantName}",
-    "Guest's screen" : "Pantalla del invitado",
-    "You were invited to a <strong>talk</strong> room or had a <strong>call</strong>" : "Te invitaron a un cuarto de <strong>conversación</strong> o tuviste una <strong>llamada</strong>",
-    "_%n other guest_::_%n other guests_" : [" %n otro invitado","%n otros invitados"],
-    ", " : ",",
-    "A group call has started" : "Una llamada en grupo ha iniciado",
-    "This call is password-protected" : "Esta llamada está protegida con contraseña",
-    "Signaling server" : "Señalizando al servidor"
+    "Guest's screen" : "Pantalla del invitado"
 },
 "nplurals=2; plural=(n != 1);");
