@@ -16,32 +16,85 @@ OC.L10N.register(
     "Join call" : "Unirse a la llamada",
     "{user} wants to talk with you" : "{user} quiere hablar contigo",
     "A group call has started in {call}" : "Una llamada en grupo ha iniciado en {call}",
-    "Validate SSL certificate" : "Validar certificado SSL",
-    "TURN server protocols" : "Protocolos del servidor TURN",
-    "UDP and TCP" : "UDP y TCP",
-    "UDP only" : "UDP únicamente",
-    "TCP only" : "TCP únicamente",
-    "[Unknown user name]" : "[Nombre de usuario desconocido]",
-    "moderator" : "moderador",
-    "Demote from moderator" : "Degradar de moderador",
-    "Promote to moderator" : "Promover a moderador",
-    "Remove participant" : "Eliminar participante",
-    "Share link" : "Compartir liga",
-    "Participants" : "Participantes",
+    "Invalid date, date format must be YYYY-MM-DD" : "La fecha es inválida, por favor sigue el formato AAAA-MM-DD",
+    "Leave call" : "Dejar la llamada",
+    "Limit to groups" : "Limitar a grupos",
+    "Everyone" : "Todos",
+    "Save changes" : "Guardar cambios",
+    "Saved!" : "¡Guardado!",
+    "None" : "Ninguno",
+    "User" : "Usuario",
+    "Disabled" : "Deshabilitado",
+    "Users" : "Usuarios",
     "Name" : "Nombre",
+    "General settings" : "Configuraciones generales",
+    "Validate SSL certificate" : "Validar certificado SSL",
     "Saved" : "Guardado",
     "Shared secret" : "Secreto compartido",
     "STUN servers" : "Servidores STUN",
     "A STUN server is used to determine the public IP address of participants behind a router." : "Un servidor STUN se está usando para determinar la IP pública de los participantes que estén detrás de un ruteador. ",
+    "TURN server protocols" : "Protocolos del servidor TURN",
+    "UDP and TCP" : "UDP y TCP",
+    "UDP only" : "UDP únicamente",
+    "TCP only" : "TCP únicamente",
+    "Copy link" : "Copiar liga",
+    "Waiting for others to join the call …" : "Esperando a que los demás se unan a la llamada ...",
+    "You can invite others in the participant tab of the sidebar" : "Puedes invitar a otras personas en la pestaña de participante del menú lateral",
+    "Share this link to invite others!" : "¡Comparte esta liga para invitar a otras personas!",
+    "Show your screen" : "Mostrar tu pantalla",
+    "Stop screensharing" : "Dejar de compartir la pantalla",
+    "Mute audio" : "Silenciar audio",
+    "Disable video" : "Deshabilitar video",
+    "Enable video" : "Habilitar el video",
+    "Screensharing options" : "Opciones de compartir pantalla",
+    "Enable screensharing" : "Habilitar compartir pantalla",
+    "Screensharing requires the page to be loaded through HTTPS." : "Compartir pantalla requiere que la página se cargue a través de HTTPS.",
+    "Sharing your screen only works with Firefox version 52 or newer." : "Compartir la pantalla sólo funciona con Firefox versión 52 o superior. ",
+    "Screensharing extension is required to share your screen." : "Se requiere de la extenisón de compartir pantalla para compartir tu pantalla. ",
+    "Please use a different browser like Firefox or Chrome to share your screen." : "Por favor usa un navegador diferente como Firefox o Chrome para compartir tu pantalla.",
+    "An error occurred while starting screensharing." : "Se presentó un error al comenzar a compartir la pantalla. ",
+    "Your screen" : "Tu pantalla",
+    "Show screen" : "Mostrar pantalla",
+    "Favorite" : "Hacer favorito",
+    "Remove from favorites" : "Eliminar de favoritos",
+    "Add to favorites" : "Agregar a tus favoritos",
+    "Contacts" : "Contactos",
+    "Loading" : "Cargando",
+    "Groups" : "Grupos",
+    "Circles" : "Círculos",
+    "Error" : "Error",
+    "Password protect" : "Proteger con contraseña",
+    "Back" : "Atrás",
+    "Close" : "Cerrar",
+    "Reply" : "Responder",
+    "Today" : "Hoy",
+    "Yesterday" : "Ayer",
+    "moderator" : "moderador",
+    "Demote from moderator" : "Degradar de moderador",
+    "Promote to moderator" : "Promover a moderador",
+    "Remove participant" : "Eliminar participante",
+    "No results" : "No hay resultados",
+    "Participants" : "Participantes",
+    "Chat" : "Chat",
+    "Settings" : "Configuraciones ",
+    "Edit" : "Editar",
+    "Dismiss" : "Descartar",
+    "Share link" : "Compartir liga",
+    "Password protection" : "Protección con contraseña",
+    "Enter a password" : "Ingresa una contraseña",
+    "Grid view" : "Vista de cuadrícula",
+    "Access to microphone & camera is only possible with HTTPS" : "El acceso al micrófono & cámara sólo es posible mediante HTTPS",
+    "Access to microphone & camera was denied" : "El acceso al micrófono & cámara fue denegado",
+    "WebRTC is not supported in your browser" : "WebRTC no está soportado en tu navegador",
+    "Please use a different browser like Firefox or Chrome" : "Por favor usa un navegador diferente como Firefox o Chrome",
+    "Error while accessing microphone & camera" : "Se pressentó un error al acceder al micrófono & cámara",
     "The password is wrong. Try again." : "La contraseña está equivoada. Por favor vuelve a intentarlo. ",
     "Password" : "Contraseña",
-    "An external signaling server can optionally be used for larger installations. Leave empty to use the internal signaling server." : "Un servidor externo de señalización puede ser, opcionalmente, utilizado para instalaciones más grandes. Déjalo vacío para usar el sevidor de señalización interno. ",
     "TURN server" : "Servidor TURN",
     "The TURN server is used to proxy the traffic from participants behind a firewall." : "El servidor TURN se usa para concentrar el tráfico de participantes detras de un firewall. ",
-    "Delete server" : "Borrar servidor",
-    "Add new server" : "Agregar un servidor nuevo ",
-    "TURN server shared secret" : "Secreto compartido del servidor TURN",
-    "Chat" : "Chat",
+    "An external signaling server can optionally be used for larger installations. Leave empty to use the internal signaling server." : "Un servidor externo de señalización puede ser, opcionalmente, utilizado para instalaciones más grandes. Déjalo vacío para usar el sevidor de señalización interno. ",
+    "Android app" : "Aplicación android",
+    "iOS app" : "Aplicación iOS",
     "Copy" : "Copiar",
     "Copied!" : "¡Copiado!",
     "Not supported!" : "¡No soportado!",
@@ -51,50 +104,26 @@ OC.L10N.register(
     "Password required" : "Contraseña requerida",
     "Cancel" : "Cancelar",
     "Submit" : "Enviar",
-    "Leave call" : "Dejar la llamada",
+    "Guests" : "Invitados",
     "Change password" : "Cambiar contraseña",
     "Set password" : "Establecer contraseña",
     "Rename" : "Renombrar",
     "You" : "Tú",
     "No messages yet, start the conversation!" : "Aún no hay mensajes. ¡!Inicia la conversación!",
     "Send" : "Enviar",
+    "Share" : "Compartir",
+    "[Unknown user name]" : "[Nombre de usuario desconocido]",
     "Error occurred while sending message" : "Se presentó un error al enviar el mensaje",
-    "Edit" : "Editar",
+    "Error while sharing" : "Se presentó un error al compartir",
     "No other people in this call" : "No hay más personas en esta llamada",
     "Waiting for {participantName} to join the call …" : "Esperando a que {participantName} se una a la llamada…",
-    "Waiting for others to join the call …" : "Esperando a que los demás se unan a la llamada ...",
-    "You can invite others in the participant tab of the sidebar" : "Puedes invitar a otras personas en la pestaña de participante del menú lateral",
-    "Share this link to invite others!" : "¡Comparte esta liga para invitar a otras personas!",
     "WebRTC is not supported in your browser :-/" : "WebRTC no se encuentra soportado en tu navegador :-/",
-    "Please use a different browser like Firefox or Chrome" : "Por favor usa un navegador diferente como Firefox o Chrome",
     "Waiting for camera and microphone permissions" : "Aguardando los permisos para la cámara y micrófono",
     "Please, give your browser access to use your camera and microphone in order to use this app." : "Por favor da acceso a tu navegador para usar tu camara y micrófono poder usar esta aplicación. ",
-    "Disable video" : "Deshabilitar video",
     "Share screen" : "Compartir la pantalla",
-    "Show your screen" : "Mostrar tu pantalla",
-    "Stop screensharing" : "Dejar de compartir la pantalla",
     "Screensharing is not supported by your browser." : "Compartir pantalla no está soportado por tu navegador. ",
-    "Screensharing requires the page to be loaded through HTTPS." : "Compartir pantalla requiere que la página se cargue a través de HTTPS.",
-    "Screensharing options" : "Opciones de compartir pantalla",
-    "Sharing your screen only works with Firefox version 52 or newer." : "Compartir la pantalla sólo funciona con Firefox versión 52 o superior. ",
-    "Screensharing extension is required to share your screen." : "Se requiere de la extenisón de compartir pantalla para compartir tu pantalla. ",
-    "Please use a different browser like Firefox or Chrome to share your screen." : "Por favor usa un navegador diferente como Firefox o Chrome para compartir tu pantalla.",
-    "An error occurred while starting screensharing." : "Se presentó un error al comenzar a compartir la pantalla. ",
-    "Enable screensharing" : "Habilitar compartir pantalla",
-    "Close" : "Cerrar",
-    "Show screen" : "Mostrar pantalla",
-    "Access to microphone & camera is only possible with HTTPS" : "El acceso al micrófono & cámara sólo es posible mediante HTTPS",
-    "Access to microphone & camera was denied" : "El acceso al micrófono & cámara fue denegado",
-    "WebRTC is not supported in your browser" : "WebRTC no está soportado en tu navegador",
-    "Error while accessing microphone & camera" : "Se pressentó un error al acceder al micrófono & cámara",
+    "Favorited" : "Marcado como favorito",
     "{participantName}'s screen" : "Pantalla de {participantName}",
-    "Guest's screen" : "Pantalla del invitado",
-    "Your screen" : "Tu pantalla",
-    "You were invited to a <strong>talk</strong> room or had a <strong>call</strong>" : "Te invitaron a un cuarto de <strong>conversación</strong> o tuviste una <strong>llamada</strong>",
-    "_%n other guest_::_%n other guests_" : [" %n otro invitado","%n otros invitados"],
-    ", " : ",",
-    "A group call has started" : "Una llamada en grupo ha iniciado",
-    "This call is password-protected" : "Esta llamada está protegida con contraseña",
-    "Signaling server" : "Señalizando al servidor"
+    "Guest's screen" : "Pantalla del invitado"
 },
 "nplurals=2; plural=(n != 1);");
