@@ -30,6 +30,9 @@ OC.L10N.register(
     "You unlocked the conversation" : "Poistit keskustelun lukituksen",
     "{actor} locked the conversation" : "{actor} lukitsi keskustelun",
     "You locked the conversation" : "Sinä lukitsit keskustelun",
+    "The conversation is now open to everyone" : "Keskustelu on nyt avoin kaikille",
+    "{actor} opened the conversation to everyone" : "{actor} avasi keskustelun kaikille",
+    "You opened the conversation to everyone" : "Avasit uuden keskustelun kaikille",
     "{actor} allowed guests" : "{actor} salli vieraat",
     "You allowed guests" : "Sinä sallit vieraat",
     "{actor} disallowed guests" : "{actor} esti vieraat",
@@ -61,6 +64,7 @@ OC.L10N.register(
     "Call with {user1}, {user2} and {user3} (Duration {duration})" : "Puhelu käyttäjien {user1}, {user2} ja {user3} kesken (Kesto {duration})",
     "Call with {user1}, {user2}, {user3} and {user4} (Duration {duration})" : "Puhelu käyttäjien {user1}, {user2}, {user3} ja {user4} kesken (Kesto {duration})",
     "Call with {user1}, {user2}, {user3}, {user4} and {user5} (Duration {duration})" : "Puhelu käyttäjien {user1}, {user2}, {user3}, {user4} ja {user5} kesken (Kesto {duration})",
+    "Write to conversation" : "Kirjoita keskusteluun",
     "%s invited you to a conversation." : "%s kutsui sinut keskusteluun.",
     "You were invited to a conversation." : "Sinut kutsuttiin keskusteluun.",
     "Conversation invitation" : "Keskustelukutsu",
@@ -68,47 +72,83 @@ OC.L10N.register(
     "Join »%s«" : "Liity »%s«",
     "Password request: %s" : "Salasanapyyntö: %s",
     "Private conversation" : "Yksityinen keskustelu",
+    "Deleted user (%s)" : "Poistettiin käyttäjä (%s)",
     "{user} sent you a private message" : "{user} lähetti sinulle yksityisviestin",
     "{user} sent a message in conversation {call}" : "{user} lähetti viestin keskusteluun {call}",
     "A deleted user sent a message in conversation {call}" : "Poistettu käyttäjä lähetti viestin keskusteluun {call}",
+    "{guest} (guest) sent a message in conversation {call}" : "{guest} (vieras) lähetti viestin keskusteluun {call}",
     "A guest sent a message in conversation {call}" : "Vieras lähetti viestin keskusteluun {call}",
+    "{user} replied to your private message" : "{user} vastasi yksityisviestiisi",
+    "{user} replied to your message in conversation {call}" : "{user} vastasi viestiisi keskustelussa {call}",
+    "A guest replied to your message in conversation {call}" : "Vieras vastasi viestiisi keskustelussa {call}",
     "{user} mentioned you in a private conversation" : "{user} mainitsi sinut yksityiskeskustelussa",
     "{user} mentioned you in conversation {call}" : "{user} mainitsi sinut keskustelussa {call}",
     "A deleted user mentioned you in conversation {call}" : "Poistettu käyttäjä mainitsi sinut keskustelussa {call}",
     "A guest mentioned you in conversation {call}" : "Vieras mainitsi sinut keskustelussa {call}",
+    "View chat" : "Näytä keskustelu",
     "{user} invited you to a private conversation" : "{user} kutsui sinut yksityiskeskusteluun",
     "Join call" : "Liity puheluun",
     "{user} invited you to a group conversation: {call}" : "{user} kutsui sinut ryhmäkeskusteluun: {call}",
+    "Answer call" : "Vastaa puheluun",
     "{user} wants to talk with you" : "{user} haluaa puhua kanssasi",
+    "Call back" : "Soita takaisin",
+    "You missed a call from {user}" : "Sinulta jäi vastaamatta puhelu käyttäjältä {user}",
     "A group call has started in {call}" : "Ryhmäpuhelu on alkanut puhelussa {call}",
     "Invalid date, date format must be YYYY-MM-DD" : "Virheellinen päiväys, päiväyksen muoto tulee olla YYYY-MM-DD",
     "Conversation not found" : "Keskustelua ei löydy",
     "Path is already shared with this room" : "Polku on jo jaettu tämän huoneen kesken",
     "Chat, video & audio-conferencing using WebRTC" : "Keskustelu ja video- sekä äänineuvottelut WebRTC:tä käyttäen",
+    "Leave call" : "Poistu puhelusta",
+    "Discuss this file" : "Keskustele tästä tiedostosta",
+    "Share this file with others to discuss it" : "Jaa tämä tiedosto muiden kanssa keskustellaksesi siitä",
+    "Share this file" : "Jaa tämä tiedosto",
+    "Join conversation" : "Liity keskusteluun",
     "Request password" : "Pyydä salasana",
     "Error requesting the password." : "Virhe pyytäessä salasanaa.",
     "This conversation has ended" : "Tämä keskustelu on päättynyt",
+    "Limit to groups" : "Rajoita ryhmiin",
+    "Guests can still join public conversations." : "Vieraat voivat silti liittyä julkisiin keskusteluihin.",
+    "Everyone" : "Kaikki",
+    "Save changes" : "Tallenna muutokset",
+    "Saving …" : "Tallennetaan…",
+    "Saved!" : "Tallennettu!",
     "None" : "Ei mitään",
     "User" : "Käyttäjä",
-    "Everyone" : "Kaikki",
     "Disabled" : "Pois käytöstä",
     "Moderators" : "Moderaattorit",
     "Users" : "Käyttäjät",
-    "TURN server URL" : "TURN-palvelimen osoite",
+    "Commands" : "Komennot",
+    "Beta" : "Beta",
+    "Name" : "Nimi",
+    "Command" : "Komento",
+    "General settings" : "Yleiset asetukset",
+    "Default notification settings" : "Ilmoitusten oletusasetukset",
+    "Default group notification" : "Ryhmän oletusilmoitus",
+    "Allow conversations on files" : "Salli keskustelut tiedostoista",
+    "All messages" : "Kaikki viestit",
+    "@-mentions only" : "Vain @-maininnat",
+    "Off" : "Pois",
     "Validate SSL certificate" : "Vahvista SSL-varmenne",
     "Delete this server" : "Poista tämä palvelin",
+    "Saved" : "Tallennettu",
+    "Add a new server" : "Lisää uusi palvelin",
+    "Shared secret" : "Jaettu salaisuus",
     "STUN server URL" : "STUN-palvelimen osoite",
+    "STUN servers" : "STUN-palvelimet",
+    "TURN server URL" : "TURN-palvelimen osoite",
     "TURN server protocols" : "TURN-palvelimen protokollat",
     "UDP and TCP" : "UDP ja TCP",
     "UDP only" : "Vain UDP",
     "TCP only" : "Vain TCP",
     "Test this server" : "Testaa tämä palvelin",
+    "TURN servers" : "TURN-palvelin",
     "Copy link" : "Kopioi linkki",
-    "No other people in this call" : "Ei muita henkilöitä tässä puhelussa",
     "Waiting for others to join the call …" : "Odotetaan muiden liittymistä puheluun...",
     "You can invite others in the participant tab of the sidebar" : "Voit kutsua muita sivupalkissa olevan Osallistujat-välilehden kautta",
     "You can invite others in the participant tab of the sidebar or share this link to invite others!" : "Voit kutsua muita sivupalkissa olevan Osallistujat-välilehden kautta tai jakamalla tämän linkin!",
     "Share this link to invite others!" : "Jaa tämä linkki kutsuaksesi muita!",
+    "Conversation link copied to clipboard." : "Keskustelulinkki kopioitu leikepöydälle.",
+    "The link could not be copied." : "Linkkiä ei voitu kopioida.",
     "Share whole screen" : "Jaa koko näyttö",
     "Share a single window" : "Jaa yksittäinen ikkuna",
     "Show your screen" : "Näytä oma näyttösi",
@@ -116,10 +156,16 @@ OC.L10N.register(
     "No audio" : "Ei ääntä",
     "Mute audio (m)" : "Mykistä äänet (m)",
     "Unmute audio (m)" : "Palauta äänet (m)",
+    "Mute audio" : "Mykistä ääni",
+    "No camera" : "Ei kameraa",
     "Disable video (v)" : "Poista video käytöstä (v)",
     "Enable video (v)" : "Ota video käyttöön (v)",
+    "Disable video" : "Poista video käytöstä",
+    "Enable video" : "Käytä videota",
     "Screensharing options" : "Näytönjakamisen valinnat",
     "Enable screensharing" : "Ota käyttöön näytönjakaminen",
+    "Screen sharing is not supported by your browser." : "Selaimesi ei tue näytönjakoa.",
+    "Screen sharing requires the page to be loaded through HTTPS." : "Näytön jakaminen vaatii sivun lataamista HTTPS-protokollalla.",
     "Screensharing requires the page to be loaded through HTTPS." : "Näytön jakaminen vaatii sivun lataamista HTTPS-protokollalla.",
     "Sharing your screen only works with Firefox version 52 or newer." : "Näytön jakaminen toimii vain Firefox-selaimen versiolla 52 tai sitä uudemmilla.",
     "Screensharing extension is required to share your screen." : "Liitännäinen vaaditaan näytön jakamiseen.",
@@ -127,71 +173,105 @@ OC.L10N.register(
     "An error occurred while starting screensharing." : "Virhe aloitettaessa näytön jakamista.",
     "Your screen" : "Sinun näyttösi",
     "Show screen" : "Näytä näyttö",
-    "Disable video" : "Poista video käytöstä",
-    "Enable video" : "Käytä videota",
+    "Mute" : "Mykistä",
+    "This conversation is read only" : "Keskustelu on kirjoitussuojattu",
+    "Drop your files to upload" : "Pudota tiedostot lähettääksesi ne",
+    "Call in progress" : "Puhelu meneillään",
     "Favorite" : "Suosikki",
+    "Chat notifications" : "Keskusteluilmoitukset",
     "Leave conversation" : "Poistu keskustelusta",
     "Delete conversation" : "Poista keskustelu",
     "Remove from favorites" : "Poista suosikeista",
     "Add to favorites" : "Lisää suosikkeihin",
+    "You: {lastMessage}" : "Sinä: {lastMessage}",
+    "No matches" : "Ei täsmääviä",
     "Conversations" : "Keskustelut",
     "Contacts" : "Yhteystiedot",
+    "Loading" : "Ladataan",
+    "No search results" : "Ei hakutuloksia",
     "Groups" : "Ryhmät",
     "Circles" : "Piirit",
-    "Loading" : "Ladataan",
+    "Contacts, groups and circles" : "Yhteystiedot, ryhmät ja piirit",
+    "Contacts and groups" : "Yhteystiedot ja ryhmät",
+    "Contacts and circles" : "Yhteystiedot ja piirit",
+    "Groups and circles" : "Ryhmät ja piirit",
+    "Other sources" : "Muut lähteet",
+    "Select default location for attachments" : "Valitse liitteiden oletussijainti",
+    "Invalid path selected" : "Valittu virheellinen polku",
+    "Error while setting attachment folder" : "Virhe asettaessa liitekansiota",
+    "Creating your conversation" : "Luodaan keskustelua",
+    "Copy conversation link" : "Kopioi keskustelulinkki",
+    "Error while creating the conversation" : "Virhe keskustelua luotaessa",
+    "Link copied to the clipboard!" : "Linkki kopioitu leikepöydälle!",
     "Error" : "Virhe",
+    "Create a new group conversation" : "Luo uusi ryhmäkeskustelu",
     "Password protect" : "Suojaa salasanalla",
+    "Add participants" : "Lisää osallistujat",
     "Back" : "Takaisin",
+    "Create conversation" : "Luo keskustelu",
     "Close" : "Sulje",
+    "Choose a password" : "Valitse salasana",
+    "Search participants" : "Etsi osallistujia",
+    "An error occurred while performing the search" : "Hakua suorittaessa tapahtui virhe",
     "Conversation name" : "Keskustelun nimi",
+    "Allow guests to join via link " : "Salli vieraiden liittyminen linkin kautta",
+    "Search conversations or contacts" : "Hae keskusteluja tai yhteystietoja",
+    "You are currently waiting in the lobby" : "Odotat parhaillaan aulassa",
+    "You are currently waiting in the lobby. This meeting is scheduled for {startTime}" : "Odotat parhaillaan aulassa. Tapaaminen on ajoitettu alkavaksi {startTime}",
     "Reply" : "Vastaa",
-    "[Unknown user name]" : "[Tuntematon käyttäjänimi]",
     "Today" : "Tänään",
     "Yesterday" : "Eilen",
+    "Write message, @ to mention someone …" : "Kirjoita viesti, käytä @-merkkiä mainitaksesi käyttäjän…",
+    "Upload new files" : "Lähetä uusia tiedostoja",
+    "Send message" : "Lähetä viesti",
     "File to share" : "Jaettava tiedosto",
     "moderator" : "moderaattori",
     "guest" : "vieras",
     "Demote from moderator" : "Alenna moderaattorista",
     "Promote to moderator" : "Ylennä moderaattoriksi",
     "Remove participant" : "Poista osallistuja",
+    "Add contacts" : "Lisää yhteystietoja",
+    "Add groups" : "Lisää ryhmiä",
+    "Add emails" : "Lisää sähköpostiosoitteita",
+    "Add circles" : "Lisää piirejä",
+    "Searching …" : "Haetaan…",
     "No results" : "Ei tuloksia",
+    "Add contacts, groups or circles" : "Lisää yhteystietoja, ryhmiä tai piirejä",
+    "Add contacts or groups" : "Lisää yhteystietoja tai ryhmiä",
+    "Add contacts or circles" : "Lisää yhteystietoja tai piirejä",
+    "Add groups or circles" : "Lisää ryhmiä tai piirejä",
+    "Add other sources" : "Lisää muita lähteitä",
+    "Add participants to the conversation" : "Lisää osallistujia keskusteluun",
     "Participants" : "Osallistujat",
+    "Chat" : "Keskustelu",
+    "Projects" : "Projektit",
+    "Settings" : "Asetukset",
+    "Display name: " : "Näyttönimi:",
+    "Edit" : "Muokkaa",
+    "Start call" : "Aloita puhelu",
+    "Dismiss" : "Hylkää",
+    "Go to file" : "Siirry tiedostoon",
     "Rename conversation" : "Nimeä keskustelu uudelleen",
-    "Guests" : "Vieraat",
     "Share link" : "Jaa linkki",
     "Password protection" : "Salasanasuojaus",
     "Enter a password" : "Syötä salasana",
-    "Chat" : "Keskustelu",
-    "Projects" : "Projektit",
-    "Edit" : "Muokkaa",
-    "Leave call" : "Poistu puhelusta",
-    "Start call" : "Aloita puhelu",
-    "Limit to groups" : "Rajoita ryhmiin",
-    "Guests can still join public conversations." : "Vieraat voivat silti liittyä julkisiin keskusteluihin.",
-    "Limit app usage to groups." : "Rajoita sovelluksen käyttö ryhmiin.",
-    "Save changes" : "Tallenna muutokset",
-    "Saving …" : "Tallennetaan…",
-    "Saved!" : "Tallennettu!",
-    "Commands" : "Komennot",
-    "Beta" : "Beta",
-    "Name" : "Nimi",
-    "Command" : "Komento",
-    "General settings" : "Yleiset asetukset",
-    "Saved" : "Tallennettu",
-    "Add a new server" : "Lisää uusi palvelin",
-    "Shared secret" : "Jaettu salaisuus",
-    "STUN servers" : "STUN-palvelimet",
-    "TURN servers" : "TURN-palvelin",
+    "Enable lobby" : "Käytä aulaa",
+    "Start time (optional)" : "Aloitusaika (valinnainen)",
+    "Exit fullscreen (f)" : "Poistu koko näytön tilasta (f)",
+    "Fullscreen (f)" : "Koko näytön tila (f)",
+    "Grid view" : "Ruudukkonäkymä",
+    "Message without mention" : "Viesti ilman mainintaa",
+    "Mention room" : "Mainitse huone",
+    "The conversation does not exist" : "Tätä keskustelua ei ole olemassa",
+    "Join a conversation or start a new one!" : "Liity keskusteluun tai aloita uusi keskustelu!",
     "Select a conversation to add to the project" : "Valitse projektiin lisättävä keskustelu",
     "Select conversation" : "Valitse keskustelu",
     "Join a conversation or start a new one" : "Liity keskusteluun tai aloita uusi",
     "Say hi to your friends and colleagues!" : "Sano hei ystävillesi ja työkavereillesi!",
     "Link to a conversation" : "Linkki keskusteluun",
-    "Please enter the password for this call" : "Anna salasana tälle puhelulle",
-    "Password required" : "Salasana vaaditaan",
-    "Password" : "Salasana",
-    "Cancel" : "Peru",
-    "Submit" : "Lähetä",
+    "Error while sharing file" : "Virhe tiedostoa jakaessa",
+    "Error while uploading file" : "Virhe tiedostoa lähettäessä",
+    "You seem to be talking while muted, please unmute yourself for others to hear you" : "Vaikuttaa siltä, että puhut vaikka sinut on mykistetty. Poista mykistys, jotta muut kuulevat sinut",
     "Access to microphone & camera is only possible with HTTPS" : "Kameran ja mikrofonin käyttäminen on mahdollista vain käytettäessä HTTPS-protokollaa",
     "Please move your setup to HTTPS" : "Siirrä asetuksesi HTTPS:n taakse",
     "Access to microphone & camera was denied" : "Yhteys mikrofoniin ja kameraan estettiin",
@@ -200,87 +280,70 @@ OC.L10N.register(
     "Error while accessing microphone & camera" : "Virhe yhdistettäessä mikrofoniin ja kameraan",
     "This conversation is password-protected" : "Tämä keskustelu on salasanasuojattu",
     "The password is wrong. Try again." : "Salasana on väärin. Yritä uudelleen.",
+    "Password" : "Salasana",
     "TURN server" : "TURN-palvelin",
     "The TURN server is used to proxy the traffic from participants behind a firewall." : "TURN-palvelinta käytetään liikenteen välittämisessä palomuurin takana oleville osallistujille.",
     "%s Talk on your mobile devices" : "%s Keskustele mobiililaitteillasi",
+    "Join conversations at any time, anywhere, on any device." : "Liity keskusteluihin milloin tahansa, mistä tahansa ja miltä tahansa laitteelta.",
     "Android app" : "Android-sovellus",
     "iOS app" : "iOS-sovellus",
-    "Delete server" : "Poista palvelin",
-    "Add new server" : "Lisää uusi palvelin",
-    "You deleted all STUN servers. As it is almost always needed, a default STUN server was added." : "Poistit kaikki STUN-palvelimet. Koska STUN-palvelinta tarvitaan lähes aina, lisäsimme oletuksena käytettävän STUN-palvelimen.",
-    "TURN server shared secret" : "TURN-palvelimen jaettu salausavain",
-    "Test server" : "Testaa palvelin",
-    "New public conversation" : "Uusi julkinen keskustelu",
-    "New group conversation" : "Uusi ryhmäkeskustelu",
+    "Enter name for a new conversation" : "Anna nimi uudelle keskustelulle",
     "{name} (public)" : "{name} (julkinen)",
     "New conversation …" : "Uusi keskustelu…",
-    "Exit fullscreen (f)" : "Poistu koko näytön tilasta (f)",
-    "Fullscreen (f)" : "Koko näytön tila (f)",
-    "Set your name in the chat window so other participants can identify you better." : "Aseta nimesi keskusteluikkunassa, jotta muut osalliset tunnistavat sinut.",
     "Copy" : "Kopioi",
     "Copied!" : "Kopioitu!",
     "Not supported!" : "Ei tuettu!",
     "Press ⌘-C to copy." : "Paina ⌘-C kopioidaksesi.",
     "Press Ctrl-C to copy." : "Paina Ctrl-C kopioidaksesi.",
     "Error while getting the room ID" : "Virhe haettaessa huoneen ID-tunnistetta",
-    "Start a conversation" : "Aloita keskustelu",
-    "Share this file with others to discuss" : "Jaa tämä tiedosto toisten kanssa keskusteltavaksi",
-    "Share" : "Jaa",
+    "Room name can not be empty" : "Huoneen nimi ei voi olla tyhjä",
+    "Please enter the password for this call" : "Anna salasana tälle puhelulle",
+    "Password required" : "Salasana vaaditaan",
+    "Cancel" : "Peru",
+    "Submit" : "Lähetä",
+    "Calls are disabled in this conversation." : "Puhelut on poistettu käytöstä tässä keskustelussa.",
+    "Guests" : "Vieraat",
+    "Webinar" : "Webinaari",
     "Change password" : "Vaihda salasana",
     "Set password" : "Aseta salasana",
-    "Go to file" : "Siirry tiedostoon",
+    "Error occurred while renaming the conversation" : "Keskustelua nimettäessä uudelleen tapahtui virhe",
     "Rename" : "Nimeä uudelleen",
-    "Conversation with {name}" : "Keskustelu henkilön {name} kanssa",
-    "Error occurred while setting password" : "Virhe salasanaa asettaessa",
     "Link copied!" : "Linkki kopioitu!",
+    "Conversation with {name}" : "Keskustelu henkilön {name} kanssa",
+    "Error occurred while making the conversation public" : "Keskustelua tehtäessä julkiseksi tapahtui virhe",
+    "Error occurred while making the conversation private" : "Keskustelua tehtäessä yksityiseksi tapahtui virhe",
+    "Error occurred while setting password" : "Virhe salasanaa asettaessa",
+    "Invalid start time format" : "Virheellinen aloitusajan muoto",
     "You" : "Sinä",
     "No messages yet, start the conversation!" : "Ei vielä viestejä, aloita keskustelu!",
     "New message …" : "Uusi viesti …",
     "Send" : "Lähetä",
+    "You can not send messages, because the conversation is locked." : "Et voi lähettää viestejä, koska keskustelu on lukittu.",
+    "The conversation is locked." : "Keskustelu on lukittu.",
+    "Share" : "Jaa",
+    "[Unknown user name]" : "[Tuntematon käyttäjänimi]",
     "The message you are trying to send is too long" : "Viesti, jonka yrität lähettää, on liian pitkä",
     "Error occurred while sending message" : "Viestiä lähettäessä tapahtui virhe",
     "Error while sharing" : "Virhe jaettaessa",
+    "No other people in this call" : "Ei muita henkilöitä tässä puhelussa",
     "Waiting for {participantName} to join the call …" : "Odotetaan henkilön {participantName} liittymistä puheluun...",
     "WebRTC is not supported in your browser :-/" : "WebRTC ei ole tuettuna selaimessasi :-/",
     "Waiting for camera and microphone permissions" : "Odotetaan käyttöoikeuden myöntämistä kameralle ja mikrofonille",
     "Please, give your browser access to use your camera and microphone in order to use this app." : "Anna selaimellesi oikeus käyttää kameraa ja mikrofonia käyttääksesi tätä sovellusta.",
-    "Mute audio" : "Mykistä ääni",
+    "Set your name in the chat window so other participants can identify you better." : "Aseta nimesi keskusteluikkunassa, jotta muut osalliset tunnistavat sinut.",
     "Share screen" : "Jaa näyttö",
     "No Camera" : "Ei kameraa",
     "Screensharing is not supported by your browser." : "Selaimesi ei tue näytönjakoa.",
     "Error while removing user from room" : "Virhe poistaessa käyttäjää huoneesta",
     "Add participant …" : "Lisää osallistuja…",
     "Favorited" : "Lisätty suosikkeihin",
-    "Always notify" : "Ilmoita aina",
-    "Notify on @-mention" : "Ilmoita @-maininnoista",
-    "Never notify" : "Älä ilmoita koskaan",
     "{participantName}'s screen" : "Henkilön {participantName} näyttö",
     "Guest's screen" : "Vieraan näyttö",
-    "_%n other guest_::_%n other guests_" : ["%n muu vieras","%n muuta vierasta"],
-    ", " : ",",
-    "Join now" : "Liity nyt",
-    "{user} sent a message in a conversation" : "{user} lähetti viestin keskusteluun",
-    "A deleted user sent a message in a conversation" : "Poistettu käyttäjä lähetti viestin keskusteluun",
-    "A guest sent a message in a conversation" : "Vieras lähetti viestin keskusteluun",
-    "{user} mentioned you in a conversation" : "{user} mainitsi sinut keskustelussa",
-    "A deleted user mentioned you in a conversation" : "Poistettu käyttäjä mainitsi sinut keskustelussa",
-    "A guest mentioned you in a conversation" : "Vieras mainitsi sinut keskustelussa",
-    "%s invited you to a private conversation" : "%s kutsui sinut yksityiskeskusteluun",
-    "%s invited you to a group conversation: %s" : "%s kutsui sinut ryhmäkeskusteluun: %s",
-    "%s invited you to a group conversation" : "%s kutsui sinut ryhmäkeskusteluun",
-    "{user} invited you to a group conversation" : "{user} kutsui sinut ryhmäkeskusteluun",
-    "A group call has started" : "Ryhmäpuhelu on alkanut",
-    "{email} requested the password to access {file}" : "{email} pyysi salasanaa voidakseen käsitellä tiedostoa {file}",
-    "Someone requested the password to access {file}" : "Joku pyysi salasanaa voidakseen käsitellä tiedostoa {file}",
-    "Unnamed conversation" : "Nimetön keskustelu",
-    "Video & audio-conferencing using WebRTC" : "Video- ja äänipuheluita WebRTC:tä käyttäen",
-    "This call is password-protected" : "Tämä puhelu on salasanasuojattu",
+    "Limit app usage to groups." : "Rajoita sovelluksen käyttö ryhmiin.",
+    "Who can start a call?" : "Kuka voi aloittaa puhelun?",
     "Join conversations at any time, any where, on any device." : "Liity keskusteluun milloin tahansa, mistä tahansa, miltä laitteelta tahansa.",
-    "Enter name for a new conversation" : "Anna nimi uudelle keskustelulle",
-    "Room name can not be empty" : "Huoneen nimi ei voi olla tyhjä",
-    "Calls are disabled in this conversation." : "Puhelut on poistettu käytöstä tässä keskustelussa.",
-    "You can not send messages, because the conversation is locked." : "Et voi lähettää viestejä, koska keskustelu on lukittu.",
-    "The conversation is locked." : "Keskustelu on lukittu.",
-    "* Microsoft Edge and Safari can now be used to participate in audio and video calls" : "* Microsoft Edgeä ja Safaria voi nyt käyttää ääni- ja videopuheluissa"
+    "Loading contacts" : "Ladataan yhteystietoja",
+    "Select participants" : "Valitse osallistujat",
+    "Contacts loading" : "Yhteystiedot latautuvat"
 },
 "nplurals=2; plural=(n != 1);");
