@@ -11,33 +11,101 @@ OC.L10N.register(
     "You attended a call with {user1}, {user2}, {user3}, {user4} and {user5}" : "השתתפת בשיחה עם {user1}, {user2}, {user3}, {user4} ועם {user5}",
     "_%n other_::_%n others_" : ["מישהו נוסף","%n נוספים","%n נוספים","%n נוספים"],
     "{actor} invited you to {call}" : "הוזמנת אל {call} על ידי {actor}",
+    "You were invited to a <strong>conversation</strong> or had a <strong>call</strong>" : "הוזמנת ל<strong>דיון</strong> או שקיבלת <strong>שיחה</strong>",
     "Talk" : "שיחה",
     "Guest" : "אורח/ת",
+    "Welcome to Nextcloud Talk!\nIn this conversation you will be informed about new features available in Nextcloud Talk." : "ברוך בואך ל־Talk מבית Nextcloud!\nבדיון הזה נעדכן אותך בנוגע לתכונות החדשות שזמינות ב־Talk מבית Nextcloud.",
+    "New in Talk 6" : "חדש ב־Talk 6",
+    "- Microsoft Edge and Safari can now be used to participate in audio and video calls" : "- ניתן מעתה להשתמש ב־Microsoft Edge וב־Safari כדי להשתת, בשיחות שמע ווידאו",
+    "New in Talk 7" : "חדש ב־Talk 7",
+    "New in Talk 8" : "חדש ב־Talk 8",
+    "There are currently no commands available." : "אין פקודות זמינות.",
+    "The command does not exist" : "הפקודה לא קיימת",
+    "An error occurred while running the command. Please ask an administrator to check the logs." : "אירעה שגיאה בעת הפעלת הפקודה. נא לבקש מהנהלת המערכת לבדוק את יומן התיעוד.",
     "{actor} created the conversation" : "הדיון נוצר על ידי {actor}",
+    "You created the conversation" : "יצרת את הדיון",
     "{actor} renamed the conversation from \"%1$s\" to \"%2$s\"" : "השם של הדיון השתנה מ־„%1$s” ל־„%2$s” על ידי {actor}",
+    "You renamed the conversation from \"%1$s\" to \"%2$s\"" : "שינית את שם הדיון מהשם „%1$s” לשם „%2$s”",
+    "{actor} started a call" : "שיחה החלה על ידי {actor}",
+    "You started a call" : "התחלת שיחה",
+    "{actor} joined the call" : "{actor} מעכשיו בשיחה",
+    "You joined the call" : "הצטרפת לשיחה",
+    "{actor} left the call" : "{actor} לא בשיחה עוד",
+    "You left the call" : "עזבת את השיחה",
+    "{actor} unlocked the conversation" : "הדיון שוחרר על ידי {actor}",
+    "You unlocked the conversation" : "שחררת את הדיון",
+    "{actor} locked the conversation" : "הדיון ננעל על ידי {actor}",
+    "You locked the conversation" : "נעלת את הדיון",
+    "The conversation is now open to everyone" : "הדיון מעתה פתוח לכול",
+    "{actor} opened the conversation to everyone" : "הדיון נפתח לכול על ידי {actor}",
+    "You opened the conversation to everyone" : "פתחת את הדיון לכול",
+    "{actor} restricted the conversation to moderators" : "הדיון הוגבל למפקחים על ידי {actor}",
+    "You restricted the conversation to moderators" : "הגבלת את הדיון למפקחים",
+    "{actor} allowed guests" : "אורחים הורשו על ידי {actor}",
+    "You allowed guests" : "הרשית אורחים",
+    "{actor} disallowed guests" : "אורחים נאסרו על ידי {actor}",
+    "You disallowed guests" : "אסרת אורחים",
+    "{actor} set a password" : "הוגדרה ססמה על ידי {actor}",
+    "You set a password" : "הגדרת ססמה",
+    "{actor} removed the password" : "הססמה הוסרה על ידי {actor}",
+    "You removed the password" : "הסרת את הססמה",
+    "{actor} added {user}" : "ההוספה של {user} בוצעה על ידי {actor}",
+    "You joined the conversation" : "הצטרפת לדיון",
+    "{actor} joined the conversation" : "הצטרפות של {actor} לדיון",
+    "You added {user}" : "הוספת את {user}",
+    "{actor} added you" : "נוספת על ידי {actor}",
+    "You left the conversation" : "עזבת את הדיון",
     "{user} sent you a private message" : "התקבלה הודעה פרטית מאת {user}",
     "{user} invited you to a private conversation" : "הוזמנת לדיון פרטי על ידי {user}",
     "Join call" : "הצטרפות לשיחה",
     "{user} invited you to a group conversation: {call}" : "הוזמנת על ידי {user} לדיון קבוצתי: {call}",
     "A group call has started in {call}" : "החלה שיחה קבוצתית תחת {call}",
     "Invalid date, date format must be YYYY-MM-DD" : "תאריך לא חוקי, תבנית התאריך חייבת להיות YYYY-MM-DD",
+    "Navigating away from the page will leave the call in {conversation}" : "ניווט מחוץ לעמוד תנתק את השיחה שב־{conversation}",
+    "Leave call" : "יציאה מהשיחה",
+    "Stay in call" : "להישאר בשיחה",
+    "Discuss this file" : "לדון על הקובץ הזה",
+    "Share this file with others to discuss it" : "שיתוף הקובץ הזה לדיונם של אחרים",
+    "Share this file" : "שיתוף הקובץ הזה",
+    "Join conversation" : "הצטרפות לדיון",
     "Request password" : "בקשת ססמה",
     "Error requesting the password." : "בקשת הססמה נכשלה.",
     "This conversation has ended" : "הדיון הסתיים",
+    "Limit to groups" : "הגבלה לקבוצות",
+    "Limit starting a call" : "הגבלת התחלת שיחה",
+    "Limit starting calls" : "הגבלת התחלת שיחות",
+    "Everyone" : "כולם",
+    "Users and moderators" : "משתמשים ומפקחים",
+    "Moderators only" : "מפקחים בלבד",
+    "Save changes" : "שמירת שינויים",
+    "Saving …" : "מתבצעת שמירה…",
+    "Saved!" : "נשמר!",
     "None" : "אין",
     "User" : "משתמש",
-    "Everyone" : "כולם",
     "Disabled" : "מושבת",
+    "Moderators" : "מפקחים",
     "Users" : "משתמשים",
-    "TURN server URL" : "כתובת שרת TURN",
+    "Commands" : "פקודות",
+    "Beta" : "בטא",
+    "Name" : "שם",
+    "Command" : "פקודה",
+    "Script" : "סקריפט",
+    "Response to" : "תגובה אל",
+    "Enabled for" : "מופעל עבור",
+    "General settings" : "הגדרות כלליות",
+    "Off" : "כבוי",
     "Validate SSL certificate" : "אימות אישור SSL",
+    "Saved" : "נשמר",
+    "Shared secret" : "סוד משותף",
     "STUN server URL" : "כתובת שרת STUN",
+    "STUN servers" : "שרתי STUN",
+    "A STUN server is used to determine the public IP address of participants behind a router." : "שרת STUN משמש לאיתור כתובת ה־IP הציבורית של המשתמשים מאחורי נתב.",
+    "TURN server URL" : "כתובת שרת TURN",
     "TURN server protocols" : "פרוטוקולים לשרתים מסוג TURN",
     "UDP and TCP" : "UDP ו־TCP",
     "UDP only" : "UDP בלבד",
     "TCP only" : "TCP בלבד",
     "Copy link" : "העתקת קישור",
-    "No other people in this call" : "אין אנשים נוספים בשיחה הזאת",
     "Waiting for others to join the call …" : "בהמתנה לאחרים להצטרף לשיחה…",
     "You can invite others in the participant tab of the sidebar" : "ניתן להזמין אחרים בלשונית המשתתפים בסרגל הצד",
     "You can invite others in the participant tab of the sidebar or share this link to invite others!" : "ניתן להזמין אחרים דרך לשונית המשתפים בסרגל הצד או לשתף את הקישור הזה כדי להזמין אחרים!",
@@ -47,8 +115,11 @@ OC.L10N.register(
     "No audio" : "אין שמע",
     "Mute audio (m)" : "השתקת שמע (m)",
     "Unmute audio (m)" : "ביטול השקת שמע (m)",
+    "Mute audio" : "השתקת שמע",
     "Disable video (v)" : "השבתת וידאו (v)",
     "Enable video (v)" : "הפעלת וידאו (v)",
+    "Disable video" : "השבתת וידאו",
+    "Enable video" : "הפעלת וידאו",
     "Screensharing options" : "אפשרויות שיתוף מסך",
     "Enable screensharing" : "הפעלת שיתוף מסך",
     "Screensharing requires the page to be loaded through HTTPS." : "לטובת שיתוף מסך יש לטעון את העמוד דרך HTTPS.",
@@ -58,59 +129,102 @@ OC.L10N.register(
     "An error occurred while starting screensharing." : "אירעה שגיאה בעת התחלת שיתוף המסך.",
     "Your screen" : "המסך שלך",
     "Show screen" : "הצגת מסך",
-    "Disable video" : "השבתת וידאו",
-    "Enable video" : "הפעלת וידאו",
+    "Drop your files to upload" : "יש לגרור לכאן קבצים כדי להעלות",
     "Favorite" : "סימון כמועדף",
+    "Conversation, " : "דיון,",
+    "Conversation settings" : "הגדרות דיון",
     "Leave conversation" : "יציאה מהדיון",
     "Delete conversation" : "מחיקת דיון",
     "Remove from favorites" : "הסרה מהמועדפים",
     "Add to favorites" : "הוספה למועדפים",
     "Conversations" : "דיונים",
     "Contacts" : "אנשי קשר",
-    "Groups" : "קבוצות",
     "Loading" : "בטעינה",
+    "Groups" : "קבוצות",
+    "Circles" : "מעגלים",
+    "Contacts and groups" : "אנשי קשר וקבוצות",
+    "Contacts and circles" : "אנשי קשר ומעגלים",
+    "Groups and circles" : "קבוצות ומעגלים",
+    "Other sources" : "מקורות אחרים",
+    "Invalid path selected" : "הנתיב שנבחר שגוי",
+    "Creating your conversation" : "הדיון שלך נוצר",
+    "All set" : "הכול מוכן",
+    "Copy conversation link" : "העתקת קישור דיון",
+    "Error while creating the conversation" : "שגיאה ביצירת הדיון",
+    "Link copied to the clipboard!" : "הקישור הועתק ללוח הגזירים!",
     "Error" : "שגיאה",
+    "Create a new group conversation" : "יצירת דיון קבוצתי חדש",
     "Password protect" : "הגנה בססמה",
+    "Add participants" : "הוספת משתתפים",
     "Back" : "חזרה",
+    "Create conversation" : "יצירת דיון",
     "Close" : "סגירה",
+    "Choose a password" : "בחירת ססמה",
+    "Search participants" : "חיפוש משתתפים",
+    "An error occurred while performing the search" : "אירעה שגיאה בעת ביצוע החיפוש",
     "Conversation name" : "שם דיון",
+    "Allow guests to join via link " : "לאפשר לאורחים להצטרף דרך קישור",
+    "Search conversations or contacts" : "חיפוש דיונים או אנשי קשר",
+    "You are currently waiting in the lobby" : "הנך בהמתנה בלובי",
+    "You are currently waiting in the lobby. This meeting is scheduled for {startTime}" : "בנך בהמתנה בלובי. פגישה זו זומנה ל־{startTime}",
     "Reply" : "תגובה",
-    "[Unknown user name]" : "[שם המשתמש לא ידוע]",
+    "[Unknown username]" : "[שם משתמש לא ידוע]",
     "Today" : "היום",
     "Yesterday" : "מחר",
     "{relativeDate}, {absoluteDate}" : "{relativeDate}, {absoluteDate}",
+    "Share files to the conversation" : "שיתוף קבצים לדיון",
+    "Upload new files" : "העלאת קבצים חדשים",
+    "Share from Files" : "שיתוף מקבצים",
+    "Send message" : "שליחת הודעה",
+    "File to share" : "קובץ לשיתוף",
     "moderator" : "מפקח/ת",
     "guest" : "אורח",
+    "Participant settings" : "הגדרות משתתפים",
     "Demote from moderator" : "הורדה מדרגת פיקוח",
     "Promote to moderator" : "קידום לדרגת פיקוח",
     "Remove participant" : "הסרת משתתף",
+    "Add contacts" : "הוספת אנשי קשר",
+    "Add groups" : "הוספת קבוצות",
+    "Add emails" : "הוספת כתובות דוא״ל",
+    "Add circles" : "הוספת מעגלים",
+    "Searching …" : "מתבצע חיפוש…",
     "No results" : "אין תוצאות",
+    "Search for more contacts" : "חיפוש אחר אנשי קשר נוספים",
+    "Add contacts, groups or circles" : "הוספת אנשי קשר, קבוצות או מעגלים",
+    "Add contacts or groups" : "הוספת אנשי קשר או קבוצות",
+    "Add contacts or circles" : "הוספת אנשי קשר או מעגלים",
+    "Add groups or circles" : "הוספת קבוצות או מעגלים",
+    "Add other sources" : "הוספת מקורות אחרים",
+    "Add participants to the conversation" : "הוספת משתתפים לדיון",
     "Participants" : "משתתפים",
+    "An error occurred while fetching the participants" : "אירעה שגיאה במהלך קבלת המשתתפים",
+    "Chat" : "צ׳אט",
+    "Projects" : "מיזמים",
+    "Settings" : "הגדרות",
+    "Display name: " : "שם תצוגה:",
+    "Edit" : "עריכה",
+    "Start call" : "התחלת שיחה",
+    "Dismiss" : "התעלמות",
+    "Go to file" : "מעבר לקובץ",
     "Rename conversation" : "שינוי שם הדיון",
-    "Guests" : "אורחים",
     "Share link" : "שיתוף קישור",
     "Password protection" : "Password protection",
     "Enter a password" : "נא להקליד ססמה",
-    "Chat" : "צ׳אט",
-    "Edit" : "עריכה",
-    "Leave call" : "יציאה מהשיחה",
-    "Start call" : "התחלת שיחה",
-    "Limit to groups" : "הגבלה לקבוצות",
-    "Limit app usage to groups." : "להגביל את השימוש ביישומון לקבוצות.",
-    "Save changes" : "שמירת שינויים",
-    "Saved!" : "נשמר!",
-    "Name" : "שם",
-    "General settings" : "הגדרות כלליות",
-    "Saved" : "נשמר",
-    "Shared secret" : "סוד משותף",
-    "STUN servers" : "שרתי STUN",
-    "A STUN server is used to determine the public IP address of participants behind a router." : "שרת STUN משמש לאיתור כתובת ה־IP הציבורית של המשתמשים מאחורי נתב.",
+    "Enable lobby" : "הפעלת לובי",
+    "Start time (optional)" : "מועד התחלה (רשות)",
+    "Exit fullscreen (f)" : "יציאה ממסך מלא (f)",
+    "Fullscreen (f)" : "מסך מלא (f)",
+    "Grid view" : "תצוגת טבלה",
+    "Message without mention" : "הודעה ללא אזכור",
+    "Mention myself" : "אזכור עצמי",
+    "Mention room" : "אזכור חדר",
+    "The conversation does not exist" : "הדיון לא קיים",
+    "Join a conversation or start a new one!" : "הצטרפות לדיון או ליצור אחד חדש!",
+    "Select a conversation to add to the project" : "בחירת דיון להוספה למיזם",
+    "Select conversation" : "בחירת דיון",
     "Join a conversation or start a new one" : "ניתן להצטרף לדיון או להתחיל באחד חדש.",
-    "Please enter the password for this call" : "נא להקליד את הססמה של השיחה הזאת",
-    "Password required" : "נדרשת ססמה",
-    "Password" : "ססמה",
-    "Cancel" : "ביטול",
-    "Submit" : "שליחה",
+    "Link to a conversation" : "קישור לדיון",
+    "Error while sharing file" : "שגיאה בשיתוף הקובץ",
     "Access to microphone & camera is only possible with HTTPS" : "גישה למיקרופון ולמצלמה אפשרית רק עם HTTPS",
     "Please move your setup to HTTPS" : "נא להעביר את התצורה שלך ל־HTTPS",
     "Access to microphone & camera was denied" : "הגישה למיקרופון ולמצלמה נדחתה",
@@ -118,63 +232,51 @@ OC.L10N.register(
     "Please use a different browser like Firefox or Chrome" : "נא להשתמש בדפדפן אחר כגון Firefox או Chrome",
     "Error while accessing microphone & camera" : "אירעה שגיאה בעת גישה למיקרופון ולמצלמה",
     "The password is wrong. Try again." : "הססמה שגויה. נא לנסות שוב.",
+    "Password" : "ססמה",
     "TURN server" : "שרת TURN",
     "The TURN server is used to proxy the traffic from participants behind a firewall." : "שרת ה־TURN משמש לתיווך התעבורה מהמשתמשים שנמצאים מאחורי חומת אש.",
     "Android app" : "יישומון ל־Android",
     "iOS app" : "יישומון ל־iOS",
-    "Delete server" : "מחיקת שרת",
-    "Add new server" : "הוספת שרת חדש",
-    "You deleted all STUN servers. As it is almost always needed, a default STUN server was added." : "מחקת את כל שרתי ה־STUN. כיוון ששרת זה נחוץ כמעט תמיד, נוסף שרת STUN כבררת מחדל.",
-    "TURN server shared secret" : "סוד משותף לשרת TURN",
-    "Test server" : "שרת בדיקה",
-    "New public conversation" : "דיון ציבורי חדש",
-    "New group conversation" : "דיון קבוצתי חדש",
     "New conversation …" : "דיון חדש…",
-    "Exit fullscreen (f)" : "יציאה ממסך מלא (f)",
-    "Fullscreen (f)" : "מסך מלא (f)",
-    "Set your name in the chat window so other participants can identify you better." : "ניתן להגדיר את שמך בחלון הצ׳אט כדי שמשתתפים אחרים יוכלו לזהות אותך בצורה נוחה יותר.",
     "Copy" : "העתקה",
     "Copied!" : "הועתק!",
     "Not supported!" : "אין תמיכה!",
     "Press ⌘-C to copy." : "להעתקה יש ללחוץ ‎⌘-C.",
     "Press Ctrl-C to copy." : "להעתקה יש ללחוץ Ctrl-C.",
-    "Start a conversation" : "התחלת דיון",
-    "Share" : "שיתוף",
+    "Please enter the password for this call" : "נא להקליד את הססמה של השיחה הזאת",
+    "Password required" : "נדרשת ססמה",
+    "Cancel" : "ביטול",
+    "Submit" : "שליחה",
+    "Guests" : "אורחים",
+    "Webinar" : "סמינר מקוון",
     "Change password" : "החלפת ססמה",
     "Set password" : "הגדרת ססמה",
     "Rename" : "שינוי שם",
+    "Link copied!" : "קישור הועתק!",
     "Conversation with {name}" : "דיון עם {name}",
     "Error occurred while setting password" : "אירעה שגיאה בעת הגדרת ססמה",
-    "Link copied!" : "קישור הועתק!",
     "You" : "אני",
     "No messages yet, start the conversation!" : "אין הודעות עדיין, ניתן להתחיל בדיון!",
     "New message …" : "הודעה חדשה…",
     "Send" : "שליחה",
+    "Share" : "שיתוף",
+    "[Unknown user name]" : "[שם המשתמש לא ידוע]",
     "Error occurred while sending message" : "אירעה שגיאה בעת שליחת ההודעה",
     "Error while sharing" : "שגיאה בעת השיתוף",
+    "No other people in this call" : "אין אנשים נוספים בשיחה הזאת",
     "Waiting for {participantName} to join the call …" : "בהמתנה להצטרפות לשיחה מצד {participantName}…",
     "WebRTC is not supported in your browser :-/" : "בדפדפן שלך אין תמיכה ב־WebRTC :-/",
     "Waiting for camera and microphone permissions" : "בהמתנה להרשאות גישה למצלמה ולמיקרופון",
     "Please, give your browser access to use your camera and microphone in order to use this app." : "נא להעניק לדפדפן שלך גישה להשתמש במצלמה ובמיקרופון שלך כדי להשתמש ביישומון הזה.",
-    "Mute audio" : "השתקת שמע",
+    "Set your name in the chat window so other participants can identify you better." : "ניתן להגדיר את שמך בחלון הצ׳אט כדי שמשתתפים אחרים יוכלו לזהות אותך בצורה נוחה יותר.",
     "Share screen" : "שיתוף המסך",
     "No Camera" : "אין מצלמה",
     "Screensharing is not supported by your browser." : "בדפדפן שלך אין תמיכה בשיתוף מסך.",
     "Add participant …" : "הוספת משתתף…",
     "Favorited" : "סומן כמועדף",
-    "Always notify" : "להודיע תמיד",
-    "Never notify" : "לא להודיע אף פעם",
     "{participantName}'s screen" : "המסך של {participantName}",
     "Guest's screen" : "המסך של האורח/ת",
-    ", " : ", ",
-    "%s invited you to a private conversation" : "הוזמנת לדיון פרטי על ידי %s",
-    "%s invited you to a group conversation: %s" : "הוזמנת על ידי %s לדיון קבוצתי: %s",
-    "%s invited you to a group conversation" : "הוזמנת לדיון קבוצתי על ידי %s",
-    "{user} invited you to a group conversation" : "הוזמנת לדיון קבוצתי על ידי {user}",
-    "A group call has started" : "החלה שיחה קבוצתית",
-    "Video & audio-conferencing using WebRTC" : "דיון עם קול ותמונה באמצעות WebRTC",
-    "This call is password-protected" : "שיחה זו מוגנת בססמה",
-    "Signaling server" : "שרת איתות",
+    "Limit app usage to groups." : "להגביל את השימוש ביישומון לקבוצות.",
     "Join conversations at any time, any where, on any device." : "ניתן להצטרף לדיון בכל עת, מכל מקום, בכל מכשיר."
 },
 "nplurals=4; plural=(n == 1 && n % 1 == 0) ? 0 : (n == 2 && n % 1 == 0) ? 1: (n % 10 == 0 && n % 1 == 0 && n > 10) ? 2 : 3;");
