@@ -2,18 +2,22 @@ OC.L10N.register(
     "spreed",
     {
     "Invalid date, date format must be YYYY-MM-DD" : "Tanggal salah, format tanggal harus TTTT-BB-HH",
+    "Limit to groups" : "Batasi ke grup",
+    "Everyone" : "Semua orang",
+    "Save changes" : "Simpan perubahan",
     "None" : "Tidak ada",
     "User" : "Pengguna",
-    "Everyone" : "Semua orang",
     "Disabled" : "Dinonaktifkan",
     "Users" : "Pengguna",
+    "Name" : "Nama",
+    "Saved" : "Disimpan",
     "Copy link" : "Salin tautan",
     "Favorite" : "Favorit",
     "Remove from favorites" : "Remove from favorites",
     "Add to favorites" : "Tambah ke favorit",
     "Contacts" : "Kontak",
-    "Groups" : "Grup",
     "Loading" : "Memuat",
+    "Groups" : "Grup",
     "Error" : "Kesalahan",
     "Password protect" : "Lindungi dengan kata sandi",
     "Back" : "Kembali",
@@ -23,18 +27,15 @@ OC.L10N.register(
     "Yesterday" : "Kemarin",
     "guest" : "pengunjung",
     "No results" : "Tidak ada hasil",
+    "Settings" : "Setelan",
+    "Edit" : "Sunting",
+    "Dismiss" : "Batal",
     "Share link" : "Bagikan tautan",
     "Password protection" : "Password protection",
     "Enter a password" : "Masukkan kata sandi",
-    "Edit" : "Sunting",
-    "Limit to groups" : "Batasi ke grup",
-    "Save changes" : "Simpan perubahan",
-    "Name" : "Nama",
-    "Saved" : "Disimpan",
-    "Password required" : "Kata sandi diperlukan",
-    "Password" : "Kata kunci",
-    "Cancel" : "Membatalkan",
+    "Grid view" : "Tampilan kotak",
     "The password is wrong. Try again." : "Kata sandi salah. Coba lagi",
+    "Password" : "Kata kunci",
     "Android app" : "Aplikasi Android",
     "iOS app" : "Aplikasi iOS",
     "Copy" : "Salin",
@@ -42,13 +43,14 @@ OC.L10N.register(
     "Not supported!" : "Tidak didukung!",
     "Press ⌘-C to copy." : "Tekan ⌘-C untuk menyalin.",
     "Press Ctrl-C to copy." : "Tekan CTRL-C untuk menyalin.",
-    "Share" : "Bagikan",
+    "Password required" : "Kata sandi diperlukan",
+    "Cancel" : "Membatalkan",
     "Change password" : "Ubah kata sandi",
     "Set password" : "Atur kata sandi",
     "Rename" : "Ubah nama",
     "Send" : "Kirim",
+    "Share" : "Bagikan",
     "Error while sharing" : "Kesalahan saat membagikan",
-    "Favorited" : "Difavoritkan",
-    ", " : "n"
+    "Favorited" : "Difavoritkan"
 },
 "nplurals=1; plural=0;");
