@@ -17,23 +17,35 @@ OC.L10N.register(
     "{user} wants to talk with you" : "{user} მომხმარებელს სურს თქვენთან საუბარი",
     "A group call has started in {call}" : "ჯგუფური ზარი დაიწყო {call}-ში",
     "Invalid date, date format must be YYYY-MM-DD" : "არასწორი თარიღი, თარიღის ფორმატი უნდა იყოს წწწწ-თთ-დდ",
+    "Leave call" : "ზარის დატოვება",
+    "Limit to groups" : "ლიმიტი ჯგუფებზე",
+    "Everyone" : "ყველა",
+    "Save changes" : "ცვილებების შენახვა",
+    "Saved!" : "შენახულია!",
     "None" : "არც ერთი",
     "User" : "მომხმარებელი",
-    "Everyone" : "ყველა",
     "Disabled" : "არაა მოქმედი",
     "Users" : "მომხმარებლები",
+    "Name" : "სახელი",
+    "General settings" : "მთავარი პარამეტრები",
     "Validate SSL certificate" : "SSL სერტიფიკატის ვალიდაცია",
+    "Saved" : "დამახსოვრდა",
+    "Shared secret" : "გაზიარებული საიდუმლო",
+    "STUN servers" : "STUN სერვერები",
+    "A STUN server is used to determine the public IP address of participants behind a router." : "STUN სერვერი როუტერს მიღმა მყოფი მონაწილეების ღია IP მისამართების დადგენისთვის.",
     "TURN server protocols" : "TURN სერვერის პროტოკოლები",
     "UDP and TCP" : "UDP და TCP",
     "UDP only" : "მხოლოდ UDP",
     "TCP only" : "მხოლოდ TCP",
     "Copy link" : "ბმულის კოპირება",
-    "No other people in this call" : "ამ ზარში მეტი ადამიანი არაა",
     "Waiting for others to join the call …" : "ზარში შემოსვლისთვის ველოდებით სხვებს …",
     "You can invite others in the participant tab of the sidebar" : "შეგიძლიათ სხვები მოიწვიოთ გვერდით ბარში, მონაწილებიის ტაბულით",
     "Share this link to invite others!" : "სხვების მოსაწვევად გააზიარეთ ეს ბმული!",
     "Show your screen" : "თქვენი ეკრანის ჩვენება",
     "Stop screensharing" : "ეკრანის გაზიარების გათიშვა",
+    "Mute audio" : "ხმის ჩახშობა",
+    "Disable video" : "ვიდეოს გათიშვა",
+    "Enable video" : "ვიდეოს ამოქმედება",
     "Screensharing options" : "ეკრანების გაზიარების პარამეტრები",
     "Enable screensharing" : "ეკრანების გაზიარების ნების დართვა",
     "Screensharing requires the page to be loaded through HTTPS." : "ეკრანების გაზიარება საჭიროებს გვერდის HTTPS პროტოკოლით ჩატვირთვას.",
@@ -43,22 +55,19 @@ OC.L10N.register(
     "An error occurred while starting screensharing." : "ეკრანის გაზიარებისას წარმოიშვა შეცდომა.",
     "Your screen" : "თქვენი ეკრანი",
     "Show screen" : "ეკრანის ჩვენება",
-    "Disable video" : "ვიდეოს გათიშვა",
-    "Enable video" : "ვიდეოს ამოქმედება",
     "Favorite" : "რჩეული",
     "Remove from favorites" : "რჩეულებიდან ამოშლა",
     "Add to favorites" : "რჩეულებში დამატება",
     "Contacts" : "კონტაქტები",
+    "Loading" : "იტვირთება",
     "Groups" : "ჯგუფები",
     "Circles" : "წრეები",
-    "Loading" : "იტვირთება",
     "Error" : "შეცდომა",
     "Password protect" : "პაროლით დაცვა",
     "Back" : "უკან",
     "Close" : "დახურვა",
     "Conversation name" : "საუბრის სახელწოდება",
     "Reply" : "პასუხი",
-    "[Unknown user name]" : "[ამოუცნობი მომხმარებელი]",
     "Today" : "დღეს",
     "Yesterday" : "გუშინ",
     "{relativeDate}, {absoluteDate}" : "{relativeDate}, {absoluteDate}",
@@ -68,74 +77,59 @@ OC.L10N.register(
     "Remove participant" : "მონაწილის ამოშლა",
     "No results" : "შედეგები არაა",
     "Participants" : "მონაწილეები",
-    "Guests" : "სტუმრები",
+    "Chat" : "ჩეთი",
+    "Settings" : "პარამეტრები",
+    "Edit" : "შეცვლა",
+    "Dismiss" : "დათხოვნა",
     "Share link" : "ბმულის გაზიარება",
     "Password protection" : "პაროლით თავდაცვა",
     "Enter a password" : "შეიყვანეთ პაროლი",
-    "Chat" : "ჩეთი",
-    "Edit" : "შეცვლა",
-    "Leave call" : "ზარის დატოვება",
-    "Limit to groups" : "ლიმიტი ჯგუფებზე",
-    "Save changes" : "ცვილებების შენახვა",
-    "Saved!" : "შენახულია!",
-    "Name" : "სახელი",
-    "General settings" : "მთავარი პარამეტრები",
-    "Saved" : "დამახსოვრდა",
-    "Shared secret" : "გაზიარებული საიდუმლო",
-    "STUN servers" : "STUN სერვერები",
-    "A STUN server is used to determine the public IP address of participants behind a router." : "STUN სერვერი როუტერს მიღმა მყოფი მონაწილეების ღია IP მისამართების დადგენისთვის.",
-    "Please enter the password for this call" : "შეყვანეთ პაროლი ზარისთვის",
-    "Password required" : "საჭიროა პაროლი",
-    "Password" : "პაროლი",
-    "Cancel" : "უარყოფა",
-    "Submit" : "გაგზავნა",
+    "Grid view" : "ბადისებური ხედი",
     "Access to microphone & camera is only possible with HTTPS" : "წვდომა მიკროფონთან და კამერასთან მხარდაჭერილია მხოლოდ HTTPS პროტოკოლით",
     "Access to microphone & camera was denied" : "წვდომა მიკროფონზე და კამერაზე აიკრძალა",
     "WebRTC is not supported in your browser" : "თქვენი ბრაუზერი WebRTC-ს არ უჭერს მხარს",
     "Please use a different browser like Firefox or Chrome" : "გთხოვთ გამოიყენოთ სხვა ბრაუზერი, Firefox-ი ან Chrome-ი",
     "Error while accessing microphone & camera" : "მიკროფონზე და კამერაზე წვდომისას წარმოიშვა შეცდომა",
     "The password is wrong. Try again." : "პაროლი არასწორია. სცადეთ ახლიდან.",
-    "An external signaling server can optionally be used for larger installations. Leave empty to use the internal signaling server." : "დიდი ინსტალაციებისთვის შესაძლებელია გარე სასიგნალო სერვერის გამოყენება. შიდა სიგნალის სერვერის გამოსაყენებლად დატოვეთ ცარიელი.",
+    "Password" : "პაროლი",
     "TURN server" : "TURN სერვერი",
     "The TURN server is used to proxy the traffic from participants behind a firewall." : "TURN სერვერი გამოიყენება ფაირვოლს უკან მყოფი მონაწილეების ტრეფიკის რწმუნებულებების გადასაცემად.",
+    "An external signaling server can optionally be used for larger installations. Leave empty to use the internal signaling server." : "დიდი ინსტალაციებისთვის შესაძლებელია გარე სასიგნალო სერვერის გამოყენება. შიდა სიგნალის სერვერის გამოსაყენებლად დატოვეთ ცარიელი.",
     "Android app" : "Android აპლიკაცია",
     "iOS app" : "iOS აპლიკაცია",
-    "Delete server" : "სერვერის გაუქმება",
-    "Add new server" : "ახალი სერვერის დამატება",
-    "TURN server shared secret" : "TURN სერვერმა გააზიარა საიდუმლო",
     "Copy" : "კოპირება",
     "Copied!" : "კოპირებულია!",
     "Not supported!" : "არ არის მხარდაჭერილი!",
     "Press ⌘-C to copy." : "დასაკოპირებლად დააჭირეთ ⌘-C-ს",
     "Press Ctrl-C to copy." : "დასაკოპირებლად დააჭირეთ Ctrl-C-ს",
-    "Share" : "გაზიარება",
+    "Please enter the password for this call" : "შეყვანეთ პაროლი ზარისთვის",
+    "Password required" : "საჭიროა პაროლი",
+    "Cancel" : "უარყოფა",
+    "Submit" : "გაგზავნა",
+    "Guests" : "სტუმრები",
     "Change password" : "პაროლის შეცვლა",
     "Set password" : "პაროლის დაყენება",
     "Rename" : "სახელის შეცვლა",
+    "Link copied!" : "ბმული დაკოპირდა!",
     "Conversation with {name}" : "საუბარი მომხმარებელთან {name}",
     "Error occurred while setting password" : "პაროლის დაყენებისას წარმოიქმნა შეცდომა",
-    "Link copied!" : "ბმული დაკოპირდა!",
     "You" : "თქვენ",
     "No messages yet, start the conversation!" : "ჯერ კომენტარები არაა, დაიწყეთ საუბარი! ",
     "Send" : "გაგზავნა",
+    "Share" : "გაზიარება",
+    "[Unknown user name]" : "[ამოუცნობი მომხმარებელი]",
     "Error occurred while sending message" : "წერილის გაგზავნისას წარმოიშვა შეცდომა",
     "Error while sharing" : "შეცდომა გაზიარების დროს",
+    "No other people in this call" : "ამ ზარში მეტი ადამიანი არაა",
     "Waiting for {participantName} to join the call …" : "ზარში შემოსვლისთვის ველოდებით მომხმარებელს {participantName} …",
     "WebRTC is not supported in your browser :-/" : "თქვენი ბრაუზერი WebRTC-ს არ უჭერს მხარს :-/",
     "Waiting for camera and microphone permissions" : "ველოდებით კამერის და მიკროფონის უფლებებს",
     "Please, give your browser access to use your camera and microphone in order to use this app." : "ამ აპლიკაციის გამოყენბისთვის გთხოვთ მიანიჭოთ ბრაუზერს წვდომა კამერასა და მიკროფონზე.",
-    "Mute audio" : "ხმის ჩახშობა",
     "Share screen" : "ეკრანის გაზიარება",
     "No Camera" : "კამერა არაა",
     "Screensharing is not supported by your browser." : "თქვენი ბრაუზერი ეკრანის გაზიარებას არ უჭერს მხარს.",
     "Favorited" : "დამატებულია რჩეულებში",
     "{participantName}'s screen" : "{participantName} მომხმარებლის ეკრანი",
-    "Guest's screen" : "სტუმრის ეკრანი",
-    "You were invited to a <strong>talk</strong> room or had a <strong>call</strong>" : "თქვენ დაგპატიჟეს ოთახში <strong>სასაუბროთ</strong> ან მიიღეთ <strong>ზარი</strong>",
-    "_%n other guest_::_%n other guests_" : ["%n სხვა სტუმარი","%n სხვა სტუმარი"],
-    ", " : ",",
-    "A group call has started" : "ჯგუფური ზარი დაწყებულია",
-    "This call is password-protected" : "ეს ზარი დაცულია პაროლით",
-    "Signaling server" : "სერვერზე იგზავნება სიგნალი"
+    "Guest's screen" : "სტუმრის ეკრანი"
 },
 "nplurals=2; plural=(n!=1);");
