@@ -1,6 +1,7 @@
 OC.L10N.register(
     "spreed",
     {
+    "a conversation" : "pokalbis",
     "(Duration %s)" : "(Trukmė %s)",
     "You attended a call with {user1}" : "Jūs dalyvavote skambutyje su {user1}",
     "_%n guest_::_%n guests_" : ["%n svečias","%n svečiai","%n svečių","%n svečias"],
@@ -15,8 +16,19 @@ OC.L10N.register(
     "Guest" : "Svečias",
     "Welcome to Nextcloud Talk!\nIn this conversation you will be informed about new features available in Nextcloud Talk." : "Sveiki atvykę į Nextcloud Pokalbius!\nŠiame pokalbyje būsite informuojami apie naujas Nextcloud Pokalbiuose prieinamas ypatybes.",
     "New in Talk 6" : "Kas naujo Pokalbiuose 6",
+    "- Microsoft Edge and Safari can now be used to participate in audio and video calls" : "- Dabar, dalyvavimui vaizdo ir garso skambučiuose gali būti naudojamos Microsoft Edge ir Safari naršyklės",
+    "- One-to-one conversations are now persistent and can not be turned into group conversations by accident anymore. Also when one of the participants leaves the conversation, the conversation is not automatically deleted anymore. Only if both participants leave, the conversation is deleted from the server" : "- Dabar, pokalbiai vienu du yra išliekantys ir daugiau nebegali būti atsitiktinai paversti į grupės pokalbius. Be to, kai kuris nors vienas dalyvis išeina iš pokalbio, pokalbis daugiau nebėra automatiškai ištrinamas. Tik tuo atveju, jei abu dalyviai išėjo iš pokalbio, pokalbis yra ištrinamas iš serverio",
+    "- You can now notify all participants by posting \"@all\" into the chat" : "- Galite siųsti pranešimą visiems dalyviams, pokalbyje parašę \"@all\"",
+    "- With the \"arrow-up\" key you can repost your last message" : "- Naudodami klavišą \"rodyklė aukštyn\" galite iš naujo paskelbti savo paskutinę žinutę",
+    "- Talk can now have commands, send \"/help\" as a chat message to see if your administrator configured some" : "- Nuo šiol, Pokalbiuose gali būti komandos. Siųskite pokalbyje žinutę \"/help\" norėdami pamatyti ar jūsų administratorius yra sukonfigūravęs kokias nors komandas",
+    "- With projects you can create quick links between conversations, files and other items" : "- Naudodami projektus galite greitai sukurti sąsajas tarp pokalbių, failų bei kitų elementų",
     "New in Talk 7" : "Kas naujo Pokalbiuose 7",
-    "- Conversations can now have a lobby. This will allow moderators to join the chat and call already to prepare the meeting, while users and guests have to wait." : "- Dabar, pokalbiuose yra laukimo salė. Tai leis moderatoriams prisijungti prie pokalbio ir skambinti, kad paruoštų susitikimą, kol tuo tarpu kiti naudotojai ir svečiai turės laukti.",
+    "- You can now mention guests in the chat" : "- Dabar, pokalbiuose galite minėti svečius",
+    "- Conversations can now have a lobby. This will allow moderators to join the chat and call already to prepare the meeting, while users and guests have to wait" : "- Dabar, pokalbiuose yra laukimo salė. Tai leis moderatoriams prisijungti prie pokalbio ir skambinti, kad paruoštų susitikimą, kol tuo tarpu kiti naudotojai ir svečiai turės laukti",
+    "New in Talk 8" : "Nauja Pokalbiuose 8",
+    "- You can now directly reply to messages giving the other users more context what your message is about" : "- Dabar, galite tiesiogiai atsakyti į žinutes, suteikdami kitiems naudotojams daugiau konteksto apie ką yra jūsų žinutė",
+    "- Searching for conversations and participants will now also filter your existing conversations, making it much easier to find previous conversations" : "- Dabar, pokalbių ir dalyvių paieška taip pat filtruos ir jūsų esamus pokalbius, todėl bus žymiai lengviau rasti ankstesnius pokalbius",
+    "- You can now add custom user groups to conversations when the circles app is installed" : "- Nuo šiol, kai turite įdiegtą ratų programėlę, galite pridėti į pokalbius tinkintas naudotojų grupes",
     "There are currently no commands available." : "Šiuo metu nėra prieinamų komandų.",
     "The command does not exist" : "Komandos nėra",
     "An error occurred while running the command. Please ask an administrator to check the logs." : "Vykdant komandą, įvyko klaida. Paprašykite administratoriaus, kad patikrintų žurnalus.",
@@ -40,6 +52,10 @@ OC.L10N.register(
     "You opened the conversation to everyone" : "Jūs atvėrėte pokalbį visiems",
     "{actor} restricted the conversation to moderators" : "{actor} apribojo pokalbį iki moderatorių",
     "You restricted the conversation to moderators" : "Jūs apribojote pokalbį iki moderatorių",
+    "{actor} allowed guests" : "{actor} leidžia svečius",
+    "You allowed guests" : "Jūs leidote svečius",
+    "{actor} disallowed guests" : "{actor} nebeleidžia svečių",
+    "You disallowed guests" : "Jūs nebeleidžiate svečių",
     "{actor} set a password" : "{actor} nustatė slaptažodį",
     "You set a password" : "Jūs nustatėte slaptažodį",
     "{actor} removed the password" : "{actor} pašalino slaptažodį",
@@ -70,17 +86,31 @@ OC.L10N.register(
     "Call with {user1}, {user2}, {user3}, {user4} and {user5} (Duration {duration})" : "Skambutis su {user1}, {user2}, {user3}, {user4} ir {user5} (Trukmė {duration})",
     "Talk to %s" : "Kalbėti su %s",
     "File is not shared, or shared but not with the user" : "Failas nėra bendrinamas arba yra bendrinamas, tačiau ne su naudotoju",
+    "Write to conversation" : "Rašyti į pokalbį",
+    "Writes event information into a conversation of your choice" : "Parašo apie įvykio informaciją į jūsų pasirinktą pokalbį",
     "%s invited you to a conversation." : "%s jus pakvietė į pokalbį.",
     "You were invited to a conversation." : "Jūs buvote pakviesti į pokalbį.",
     "Conversation invitation" : "Pakvietimas į pokalbį",
     "Click the button below to join." : "Norėdami prisijungti, spustelėkite mygtuką žemiau.",
     "Join »%s«" : "Prisijungti prie »%s«",
-    "Password request: %s" : "Slaptažodžio užklausa: %s",
+    "Password request: %s" : "Slaptažodžio prašymas: %s",
     "Private conversation" : "Privatus pokalbis",
     "Deleted user (%s)" : "Ištrintas naudotojas (%s)",
     "{user} sent you a private message" : "{user} išsiuntė jums privačią žinutę",
+    "{user} sent a message in conversation {call}" : "{user} išsiuntė žinutę pokalbyje {call}",
+    "A deleted user sent a message in conversation {call}" : "Ištrintas naudotojas išsiuntė žinutę pokalbyje {call}",
+    "{guest} (guest) sent a message in conversation {call}" : "{guest} (svečias) išsiuntė žinutę pokalbyje {call}",
+    "A guest sent a message in conversation {call}" : "Svečias išsiuntė žinutę pokalbyje {call}",
     "{user} replied to your private message" : "{user} atsakė į jūsų privačią žinutę",
-    "{user} mentioned you in a private conversation" : "{user} jus paminėjo privačiame pokalbyje",
+    "{user} replied to your message in conversation {call}" : "{user} atsakė į jūsų žinutę pokalbyje {call}",
+    "A deleted user replied to your message in conversation {call}" : "Ištrintas naudotojas atsakė į jūsų žinutę pokalbyje {call}",
+    "{guest} (guest) replied to your message in conversation {call}" : "{guest} (svečias) atsakė į jūsų žinutę pokalbyje {call}",
+    "A guest replied to your message in conversation {call}" : "Svečias atsakė į jūsų žinutę pokalbyje {call}",
+    "{user} mentioned you in a private conversation" : "{user} paminėjo jus privačiame pokalbyje",
+    "{user} mentioned you in conversation {call}" : "{user} paminėjo jus pokalbyje {call}",
+    "A deleted user mentioned you in conversation {call}" : "Ištrintas naudotojas paminėjo jus pokalbyje {call}",
+    "{guest} (guest) mentioned you in conversation {call}" : "{guest} (svečias) paminėjo jus pokalbyje {call}",
+    "A guest mentioned you in conversation {call}" : "Svečias paminėjo jus pokalbyje {call}",
     "View chat" : "Rodyti pokalbį",
     "{user} invited you to a private conversation" : "{user} jus pakvietė į privatų pokalbį",
     "Join call" : "Prisijungti prie skambučio",
@@ -91,39 +121,74 @@ OC.L10N.register(
     "You missed a call from {user}" : "Jūs praleidote skambutį nuo {user}",
     "A group call has started in {call}" : "Grupės skambutis prasidėjo ties {call}",
     "You missed a group call in {call}" : "Jūs praleidote grupės skambutį ties {call}",
-    "{email} is requesting the password to access {file}" : "{email} užklausia slaptažodžio, kad gautų prieigą prie {file}",
+    "{email} is requesting the password to access {file}" : "{email} prašo slaptažodžio, kad gautų prieigą prie {file}",
+    "{email} tried to request the password to access {file}" : "{email} bandė paprašyti slaptažodžio, kad gautų prieigą prie {file}",
+    "Someone is requesting the password to access {file}" : "Kažkas prašo slaptažodžio, kad gautų prieigą prie {file}",
+    "Someone tried to request the password to access {file}" : "Kažkas bandė paprašyti slaptažodžio, kad gautų prieigą prie {file}",
     "Invalid date, date format must be YYYY-MM-DD" : "Netinkama data, datos formatas privalo būti MMMM-mm-dd",
     "Conversation not found" : "Pokalbis nerastas",
     "Path is already shared with this room" : "Kelias jau yra bendrinamas su šiuo kambariu",
     "Chat, video & audio-conferencing using WebRTC" : "Pokalbiai, vaizdo ir garso konferencijos naudojant WebRTC",
+    "Leave call" : "Išeiti iš skambučio",
     "Discuss this file" : "Aptarkite šį failą",
     "Share this file with others to discuss it" : "Bendrinti šį failą su kitais, norint jį aptarti",
     "Share this file" : "Bendrinti šį failą",
     "Join conversation" : "Prisijungti prie pokalbio",
-    "Request password" : "Užklausti slaptažodžio",
-    "Error requesting the password." : "Klaida užklausiant slaptažodį.",
+    "Request password" : "Prašyti slaptažodžio",
+    "Error requesting the password." : "Klaida prašant slaptažodžio.",
     "This conversation has ended" : "Šis pokalbis pasibaigė",
+    "Limit to groups" : "Apriboti iki grupių",
+    "Guests can still join public conversations." : "Svečiai vis tiek gali prisijungti prie viešų pokalbių.",
+    "When a call has started, everyone with access to the conversation can join the call." : "Prasidėjus skambučiui, visi, turintys prieigą prie pokalbio, gali prisijungti prie skambučio.",
+    "Everyone" : "Visi",
+    "Users and moderators" : "Naudotojai ir moderatoriai",
+    "Moderators only" : "Tik moderatoriai",
+    "Save changes" : "Įrašyti pakeitimus",
+    "Saving …" : "Įrašoma …",
+    "Saved!" : "Įrašyta!",
     "None" : "Nėra",
     "User" : "Naudotojas",
-    "Everyone" : "Visi",
     "Disabled" : "Išjungta",
     "Moderators" : "Moderatoriai",
     "Users" : "Naudotojai",
-    "TURN server URL" : "TURN serverio URL",
+    "Commands" : "Komandos",
+    "Beta" : "Beta",
+    "Name" : "Vardas",
+    "Command" : "Komanda",
+    "Script" : "Scenarijus",
+    "General settings" : "Bendri nustatymai",
+    "Integration into other apps" : "Integracija į kitas programėles",
+    "All messages" : "Visos žinutės",
+    "@-mentions only" : "Tik @ paminėjimai",
+    "Off" : "Išjungta",
+    "Signaling server URL" : "Signalinio serverio URL",
     "Delete this server" : "Ištrinti šį serverį",
+    "Status: Checking connection" : "Būsena: Tikrinamas ryšys",
+    "Error: Can not connect to server" : "Klaida: Nepavyksta prisijungti prie serverio",
+    "Error: Unknown error occurred" : "Klaida: Įvyko nežinoma klaida",
+    "Signaling servers" : "Signaliniai serveriai",
+    "Saved" : "Įrašyta",
+    "Add a new server" : "Pridėti naują serverį",
+    "An external signaling server should optionally be used for larger installations. Leave empty to use the internal signaling server." : "Didesniems diegimams pasirinktinai turėtų būti naudojamas signalinis serveris. Palikite tuščią norėdami naudoti vidinį signalinį serverį.",
+    "Please note that calls with more than 4 participants without external signaling server, participants can experience connectivity issues and cause high load on participating devices." : "Turėkite omenyje, kad skambučiuose su daugiau kaip 4 dalyviais be išorinio signalinio serverio, dalyviai gali patirti ryšio problemas ir sukelti didelę apkrovą dalyvaujantiems įrenginiams.",
+    "Don't warn about connectivity issues in calls with more than 4 participants" : "Neįspėti apie jungiamumo problemas skambučiuose su daugiau kaip 4 dalyviais",
     "STUN server URL" : "STUN serverio URL",
+    "STUN servers" : "STUN serveriai",
+    "TURN server URL" : "TURN serverio URL",
     "TURN server secret" : "TURN serverio paslaptis",
     "TURN server protocols" : "TURN serverio protokolai",
     "UDP and TCP" : "UDP ir TCP",
     "UDP only" : "Tik UDP",
     "TCP only" : "Tik TCP",
     "Test this server" : "Išbandyti šį serverį",
+    "TURN servers" : "TURN serveriai",
     "Copy link" : "Kopijuoti nuorodą",
-    "No other people in this call" : "Šiame skambutyje nėra kitų žmonių",
     "Waiting for others to join the call …" : "Laukiama, kol kiti prisijungs prie skambučio…",
     "You can invite others in the participant tab of the sidebar" : "Galite pakviesti kitus žmonės šoninėje juostoje, dalyvių kortelėje",
     "You can invite others in the participant tab of the sidebar or share this link to invite others!" : "Galite pakviesti kitus žmonės šoninėje juostoje, dalyvių kortelėje arba bendrindami šią nuorodą, skirtą pakviesti kitus asmenis!",
     "Share this link to invite others!" : "Bendrinkite šią nuorodą, norėdami pakviesti kitus!",
+    "Conversation link copied to clipboard." : "Pokalbio nuoroda nukopijuota į iškarpinę.",
+    "The link could not be copied." : "Nepavyko nukopijuoti nuorodos.",
     "Share whole screen" : "Bendrinti visą ekraną",
     "Share a single window" : "Bendrinti vieną langą",
     "Show your screen" : "Rodyti savo ekraną",
@@ -131,13 +196,19 @@ OC.L10N.register(
     "No audio" : "Nėra jokio garso",
     "Mute audio (m)" : "Nutildyti garsą (m)",
     "Unmute audio (m)" : "Įjungti garsą (m)",
+    "Mute audio" : "Nutildyti garsą",
+    "Unmute audio" : "Įjungti garsą",
     "No camera" : "Nėra kameros",
     "Disable video (v)" : "Išjungti vaizdą (v)",
     "Enable video (v)" : "Įjungti vaizdą (v)",
     "Enable video (v) - Your connection will be briefly interrupted when enabling the video for the first time" : "Įjungti vaizdą (v) - Pirmą kartą įjungiant vaizdą, jūsų ryšys bus trumpam pertrauktas",
+    "Disable video" : "Išjungti vaizdą",
+    "Enable video" : "Įjungti vaizdą",
+    "Enable video. Your connection will be briefly interrupted when enabling the video for the first time" : "Įjungti vaizdą. Pirmą kartą įjungiant vaizdą, jūsų ryšys bus trumpam pertrauktas",
     "Screensharing options" : "Ekrano bendrinimo parinktys",
     "Enable screensharing" : "Įjungti ekrano bendrinimą",
     "Screen sharing is not supported by your browser." : "Jūsų naršyklė nepalaiko ekrano bendrinimo.",
+    "Screen sharing requires the page to be loaded through HTTPS." : "Ekrano bendrinimas reikalauja, kad puslapis būtų įkeltas per HTTPS.",
     "Screensharing requires the page to be loaded through HTTPS." : "Ekrano bendrinimas reikalauja, kad puslapis būtų įkeltas per HTTPS.",
     "Sharing your screen only works with Firefox version 52 or newer." : "Ekrano bendrinimas veikia tik naudojant Firefox 52 arba naujesnę versiją.",
     "Screensharing extension is required to share your screen." : "Norint bendrinti ekraną yra reikalingas ekrano bendrinimo plėtinys.",
@@ -145,37 +216,43 @@ OC.L10N.register(
     "An error occurred while starting screensharing." : "Pradedant ekrano bendrinimą, įvyko klaida.",
     "Your screen" : "Jūsų ekranas",
     "Show screen" : "Rodyti ekraną",
-    "Disable video" : "Išjungti vaizdą",
-    "Enable video" : "Įjungti vaizdą",
+    "This conversation is read only" : "Šis pokalbis yra tik skaitymui",
     "Favorite" : "Mėgstamas",
+    "Conversation settings" : "Pokalbio nustatymai",
     "Chat notifications" : "Pokalbio pranešimai",
-    "All messages" : "Visos žinutės",
-    "@-mentions only" : "Tik @ paminėjimai",
-    "Off" : "Išjungta",
     "Leave conversation" : "Išeiti iš pokalbio",
     "Delete conversation" : "Ištrinti pokalbį",
     "Remove from favorites" : "Šalinti iš mėgstamų",
     "Add to favorites" : "Pridėti į mėgstamus",
+    "You: {lastMessage}" : "Jūs: {lastMessage}",
+    "{actor}: {lastMessage}" : "{actor}: {lastMessage}",
+    "Do you really want to delete \"{displayName}\"?" : "Ar tikrai norite ištrinti \"{displayName}\"?",
     "You need to promote a new moderator before you can leave the conversation." : "Prieš išeidami iš pokalbio, turite paaukštinti naują moderatorių.",
     "Conversations" : "Pokalbiai",
     "Contacts" : "Adresatai",
-    "Groups" : "Grupės",
-    "Circles" : "Ratai",
     "Loading" : "Įkeliama",
     "No search results" : "Nėra paieškos rezultatų",
+    "Groups" : "Grupės",
+    "Circles" : "Ratai",
+    "Default location for attachments" : "Numatytoji priedų vieta",
     "Contacts, groups and circles" : "Adresatai, grupės ir ratai",
     "Contacts and groups" : "Adresatai ir grupės",
     "Contacts and circles" : "Adresatai ir ratai",
     "Groups and circles" : "Grupės ir ratai",
     "Other sources" : "Kiti šaltiniai",
+    "Select default location for attachments" : "Pasirinkti numatytąją vietą priedams",
+    "Invalid path selected" : "Pasirinktas neteisingas kelias",
+    "Error while setting attachment folder" : "Klaida nustatant priedų aplanką",
+    "Creating your conversation" : "Kuriamas jūsų pokalbis",
+    "All set" : "Viskas paruošta",
     "Copy conversation link" : "Kopijuoti pokalbio nuorodą",
     "Error while creating the conversation" : "Klaida kuriant pokalbį",
     "Link copied to the clipboard!" : "Nuoroda nukopijuota į iškarpinę!",
     "Error" : "Klaida",
     "Create a new group conversation" : "Sukurti naują grupės pokalbį",
     "Password protect" : "Apsaugoti slaptažodžiu",
-    "Back" : "Atgal",
     "Add participants" : "Pridėti dalyvius",
+    "Back" : "Atgal",
     "Create conversation" : "Sukurti pokalbį",
     "Close" : "Užverti",
     "Search participants" : "Ieškoti dalyvių",
@@ -186,66 +263,68 @@ OC.L10N.register(
     "You are currently waiting in the lobby" : "Šiuo metu laukiate laukimo salėje",
     "You are currently waiting in the lobby. This meeting is scheduled for {startTime}" : "Šiuo metu laukiate laukimo salėje. Šio susitikimo pradžia yra suplanuota {startTime}",
     "Reply" : "Atsakyti",
-    "[Unknown user name]" : "[Nežinomas naudotojo vardas]",
+    "[Unknown username]" : "[Nežinomas naudotojo vardas]",
     "Today" : "Šiandien",
     "Yesterday" : "Vakar",
     "{relativeDate}, {absoluteDate}" : "{relativeDate}, {absoluteDate}",
+    "Write message, @ to mention someone …" : "Rašykite žinutę, naudokite @ norėdami kažką paminėti…",
+    "Share from Files" : "Bendrinti iš Failų",
+    "Send message" : "Siųsti žinutę",
     "File to share" : "Failas, kurį bendrinti",
-    "Invalid path selected" : "Pasirinktas neteisingas kelias",
-    "Error while sharing file" : "Klaida bendrinant failą",
     "moderator" : "moderatorius",
     "guest" : "svečias",
+    "Participant settings" : "Dalyvio nustatymai",
     "Demote from moderator" : "Pažeminti iš moderatorių",
     "Promote to moderator" : "Paaukštinti į moderatorius",
     "Remove participant" : "Šalinti dalyvį",
-    "Contacts loading" : "Įkeliami adresatai",
-    "No results" : "Rezultatų nėra",
-    "Add participants to the conversation" : "Pridėti dalyvius į pokalbį",
-    "Participants" : "Dalyviai",
     "Add contacts" : "Pridėti adresatus",
     "Add groups" : "Pridėti grupes",
     "Add emails" : "Pridėti el. paštus",
     "Add circles" : "Pridėti ratus",
     "Searching …" : "Ieškoma…",
+    "No results" : "Rezultatų nėra",
+    "Search for more contacts" : "Ieškoti daugiau adresatų",
+    "Add contacts, groups or circles" : "Pridėti adresatus, grupes ar ratus",
+    "Add contacts or groups" : "Pridėti adresatus ar grupes",
+    "Add contacts or circles" : "Pridėti adresatus ar ratus",
+    "Add groups or circles" : "Pridėti grupes ar ratus",
+    "Add other sources" : "Pridėti kitus šaltinius",
+    "Add participants to the conversation" : "Pridėti dalyvius į pokalbį",
+    "Participants" : "Dalyviai",
+    "An error occurred while fetching the participants" : "Gaunant dalyvius, įvyko klaida",
+    "Chat" : "Pokalbis",
+    "Projects" : "Projektai",
+    "Settings" : "Nustatymai",
+    "Display name: " : "Rodomas vardas: ",
+    "Edit" : "Taisyti",
+    "Start call" : "Pradėti skambutį",
+    "Dismiss" : "Atmesti",
+    "Toggle fullscreen" : "Perjungti visą ekraną",
+    "Go to file" : "Pereiti į failą",
     "Rename conversation" : "Pervadinti pokalbį",
-    "Guests" : "Svečiai",
     "Share link" : "Bendrinimo nuoroda",
-    "Password protection" : "Password protection",
+    "Password protection" : "Apsauga slaptažodžiu",
     "Enter a password" : "Enter a password",
-    "Webinar" : "Internetinis seminaras",
     "Enable lobby" : "Įjungti laukimo salę",
     "Start time (optional)" : "Pradžios laikas (nebūtinas)",
-    "Projects" : "Projektai",
-    "Edit" : "Taisyti",
-    "Leave call" : "Išeiti iš skambučio",
-    "Start call" : "Pradėti skambutį",
-    "Limit to groups" : "Apriboti iki grupių",
-    "Guests can still join public conversations." : "Svečiai vis tiek gali prisijungti prie viešųjų pokalbių.",
-    "Save changes" : "Įrašyti pakeitimus",
-    "Saving …" : "Įrašoma …",
-    "Saved!" : "Įrašyta!",
-    "Commands" : "Komandos",
-    "Beta" : "Beta",
-    "Name" : "Vardas",
-    "Command" : "Komanda",
-    "Script" : "Scenarijus",
-    "General settings" : "Bendri nustatymai",
-    "Start calls" : "Pradeda skambučius",
-    "Who can start a call?" : "Kas gali pradėti skambutį?",
-    "When a call has started, everyone with access to the conversation can join the call." : "Prasidėjus skambučiui, visi, turintys prieigą prie pokalbio, gali prisijungti prie skambučio.",
-    "Users and moderators" : "Naudotojai ir moderatoriai",
-    "Moderators only" : "Tik moderatoriai",
-    "Saved" : "Įrašyta",
-    "Add a new server" : "Pridėti naują serverį",
-    "Don't warn about connectivity issues in calls with more than 4 participants" : "Neįspėti apie jungiamumo problemas skambučiuose su daugiau kaip 4 dalyviais",
-    "STUN servers" : "STUN serveriai",
-    "TURN servers" : "TURN serveriai",
+    "Exit fullscreen (f)" : "Išeiti iš viso ekrano (f)",
+    "Fullscreen (f)" : "Visas ekranas (f)",
+    "Grid view" : "Tinklelio rodinys",
+    "Message without mention" : "Rašyti be paminėjimo",
+    "Mention myself" : "Paminėti save",
+    "Mention room" : "Paminėti kambarį",
+    "The conversation does not exist" : "Pokalbio nėra",
+    "Join a conversation or start a new one!" : "Prisijunkite prie pokalbio arba pradėkite naują!",
+    "Join a conversation or start a new one" : "Prisijunkite prie pokalbio arba pradėkite naują",
     "Say hi to your friends and colleagues!" : "Pasisveikinkite su savo draugais ir kolegomis!",
-    "Please enter the password for this call" : "Įveskite šio skambučio slaptažodį",
-    "Password required" : "Reikalingas slaptažodis",
-    "Password" : "Slaptažodis",
-    "Cancel" : "Atsisakyti",
-    "Submit" : "Pateikti",
+    "The browser you're using is not fully supported by Nextcloud Talk. Please use the latest version of Mozilla Firefox, Microsoft Edge, Google Chrome or Apple Safari." : "Nextcloud Pokalbiai pilnai nepalaiko jūsų naudojamos naršyklės. Naudokite naujausią Mozilla Firefox, Microsoft Edge, Google Chrome ar Apple Safari versiją.",
+    "Nextcloud is in maintenance mode, please reload the page" : "Nextcloud yra techninės priežiūros veiksenoje, įkelkite puslapį iš naujo",
+    "Nextcloud Talk was updated, please reload the page" : "Nextcloud Pokalbiai buvo atnaujinti, įkelkite puslapį iš naujo",
+    "Error while sharing file" : "Klaida bendrinant failą",
+    "Sending signaling message has failed." : "Nepavyko išsiųsti signalinės žinutės.",
+    "Establishing signaling connection is taking longer than expected …" : "Signalinio ryšio užmezgimas trunka ilgiau nei tikėtasi…",
+    "Failed to establish signaling connection. Retrying …" : "Nepavyko užmegzti signalinio ryšio. Bandoma iš naujo…",
+    "You seem to be talking while muted, please unmute yourself for others to hear you" : "Atrodo, kad kalbate su išjungtu mikrofonu, įjunkite savo garsą, jei norite, kad kiti jus girdėtų",
     "This is taking longer than expected. Are the media permissions already granted (or rejected)? If yes please restart your browser, as audio and video are failing" : "Tai užtrunka ilgiau, nei tikėtasi. Ar medijos leidimai jau yra suteikti (arba atmesti)? Jeigu taip, tuomet paleiskite savo naršyklę iš naujo, nes garsas ir vaizdas patiria nesėkmę",
     "Access to microphone & camera is only possible with HTTPS" : "Prieiga prie mikrofono ir kameros yra įmanoma tik naudojant HTTPS",
     "Please move your setup to HTTPS" : "Perkelkite savo sąranką į HTTPS",
@@ -255,46 +334,59 @@ OC.L10N.register(
     "Error while accessing microphone & camera" : "Klaida, gaunant prieigą prie mikrofono ir kameros",
     "This conversation is password-protected" : "Šis pokalbis yra apsaugotas slaptažodžiu",
     "The password is wrong. Try again." : "Slaptažodis neteisingas. Bandykite dar kartą.",
+    "Password" : "Slaptažodis",
     "TURN server" : "TURN serveris",
+    "An external signaling server can optionally be used for larger installations. Leave empty to use the internal signaling server." : "Didesniems diegimams pasirinktinai gali būti naudojamas signalinis serveris. Palikite tuščią norėdami naudoti vidinį signalinį serverį.",
     "%s Talk on your mobile devices" : "%s Pokalbiai jūsų mobiliuosiuose įrenginiuose",
+    "Join conversations at any time, anywhere, on any device." : "Prisijunkite prie pokalbių bet kur, bet kada, bet kokiame įrenginyje.",
     "Android app" : "Android programėlė",
     "iOS app" : "iOS programėlė",
-    "Delete server" : "Ištrinti serverį",
-    "Add new server" : "Pridėti naują serverį",
-    "Test server" : "Išbandyti serverį",
-    "New public conversation" : "Naujas viešas pokalbis",
-    "New group conversation" : "Naujas grupės pokalbis",
+    "Enter name for a new conversation" : "Įveskite naujo pokalbio pavadinimą",
     "{name} (public)" : "{name} (viešas)",
     "New conversation …" : "Naujas pokalbis …",
-    "Exit fullscreen (f)" : "Išeiti iš viso ekrano (f)",
-    "Fullscreen (f)" : "Visas ekranas (f)",
-    "Set your name in the chat window so other participants can identify you better." : "Nustatykite pokalbio lange savo vardą, kad kiti dalyviai galėtų lengviau jus atpažinti.",
+    "Calls with more than 4 participants without an external signaling server can experience connectivity issues and cause high load on participating devices." : "Skambučiuose su daugiau kaip 4 dalyviais be išorinio signalinio serverio gali būti patiriamos ryšio problemos ir sukeliama didelė apkrova dalyvaujantiems įrenginiams.",
     "Copy" : "Kopijuoti",
     "Copied!" : "Nukopijuota!",
     "Not supported!" : "Nepalaikoma!",
     "Press ⌘-C to copy." : "Norėdami nukopijuoti, paspauskite ⌘-C.",
     "Press Ctrl-C to copy." : "Paspauskite Vald-C, norėdami nukopijuoti.",
     "Error while getting the room ID" : "Klaida gaunant kambario ID",
-    "Share" : "Bendrinti",
+    "Room name can not be empty" : "Kambario pavadinimas negali būti tuščias",
+    "Please enter the password for this call" : "Įveskite šio skambučio slaptažodį",
+    "Password required" : "Reikalingas slaptažodis",
+    "Cancel" : "Atsisakyti",
+    "Submit" : "Pateikti",
+    "Calls are disabled in this conversation." : "Šiame pokalbyje skambinti negalima.",
+    "Guests" : "Svečiai",
+    "Webinar" : "Internetinis seminaras",
+    "Only moderators can enter the conversation when the lobby is enabled" : "Įjungus laukimo salę, į pokalbį galės užeiti tik moderatoriai",
     "Change password" : "Pakeisti slaptažodį",
     "Set password" : "Nustatyti slaptažodį",
-    "Go to file" : "Pereiti į failą",
+    "Error occurred while renaming the conversation" : "Klaida pervadinant pokalbį",
     "Rename" : "Pervadinti",
+    "Link copied!" : "Nuoroda nukopijuota!",
     "Conversation with {name}" : "Pokalbis su {name}",
     "Error occurred while setting password" : "Nustatant slaptažodį, atsirado klaidų",
-    "Link copied!" : "Nuoroda nukopijuota!",
+    "Error occurred while changing lobby state" : "Klaida keičiant laukimo salės būseną",
+    "Invalid start time format" : "Neteisingas pradžios laiko formatas",
+    "Error occurred while setting the lobby start time" : "Klaida nustatant laukimo salės pradžios laiką",
     "You" : "Jūs",
     "No messages yet, start the conversation!" : "Kol kas žinučių nėra, pradėkite pokalbį!",
     "New message …" : "Nauja žinutė…",
     "Send" : "Siųsti",
+    "You can not send messages, because the conversation is locked." : "Negalite siųsti žinučių, nes pokalbis užrakintas.",
+    "The conversation is locked." : "Pokalbis užrakintas.",
+    "Share" : "Bendrinti",
+    "[Unknown user name]" : "[Nežinomas naudotojo vardas]",
     "The message you are trying to send is too long" : "Žinutė, kurią bandote išsiųsti yra pernelyg ilga",
     "Error occurred while sending message" : "Siunčiant žinutę, įvyko klaida",
     "Error while sharing" : "Klaida bendrinant",
+    "No other people in this call" : "Šiame skambutyje nėra kitų žmonių",
     "Waiting for {participantName} to join the call …" : "Laukiama, kol {participantName} prisijungs prie skambučio…",
     "WebRTC is not supported in your browser :-/" : "Jūsų naršyklėje WebRTC nėra palaikoma :-/",
     "Waiting for camera and microphone permissions" : "Laukiama kameros ir mikrofono leidimų",
     "Please, give your browser access to use your camera and microphone in order to use this app." : "Norėdami naudoti šią programėlę, suteikite savo naršyklei prieigą naudoti jūsų kamerą ir mikrofoną.",
-    "Mute audio" : "Nutildyti garsą",
+    "Set your name in the chat window so other participants can identify you better." : "Nustatykite pokalbio lange savo vardą, kad kiti dalyviai galėtų lengviau jus atpažinti.",
     "Share screen" : "Bendrinti ekraną",
     "No Camera" : "Nėra jokios kameros",
     "Screensharing is not supported by your browser." : "Jūsų naršyklė nepalaiko ekrano bendrinimo.",
@@ -303,40 +395,15 @@ OC.L10N.register(
     "Error while removing user from room" : "Klaida šalinant naudotoją iš kambario",
     "Add participant …" : "Pridėti dalyvį…",
     "Favorited" : "Pažymėtas mėgstamu",
-    "Always notify" : "Visada pranešti",
-    "Notify on @-mention" : "Pranešti paminėjus @",
-    "Never notify" : "Niekada nepranešti",
     "{participantName}'s screen" : "Dalyvio {participantName} ekranas",
     "Guest's screen" : "Svečio ekranas",
-    "You were invited to a <strong>talk</strong> room or had a <strong>call</strong>" : "Jūs buvote pakviesti į <strong>pokalbių</strong> kambarį arba jums <strong>skambino</strong>",
-    "_%n other guest_::_%n other guests_" : ["ir dar %n svečias","ir dar %n svečiai","ir dar %n svečių","ir dar %n svečias"],
-    ", " : ", ",
-    "{user} sent a message in a conversation" : "{user} išsiuntė žinutę į pokalbį",
-    "A deleted user sent a message in a conversation" : "Ištrintas naudotojas išsiuntė žinutę į pokalbį",
-    "A guest sent a message in a conversation" : "Svečias išsiuntė žinutę į pokalbį",
-    "{user} mentioned you in a conversation" : "{user} paminėjo jus pokalbyje",
-    "A deleted user mentioned you in a conversation" : "Ištrintas naudotojas paminėjo jus pokalbyje",
-    "A guest mentioned you in a conversation" : "Svečias paminėjo jus pokalbyje",
-    "%s invited you to a private conversation" : "%s jus pakvietė į privatų pokalbį",
-    "%s invited you to a group conversation: %s" : "%s jus pakvietė į grupės pokalbį: %s",
-    "%s invited you to a group conversation" : "%s jus pakvietė į grupės pokalbį",
-    "{user} invited you to a group conversation" : "{user} jus pakvietė į grupės pokalbį",
-    "A group call has started" : "Prasidėjo grupės skambutis",
-    "{email} requested the password to access {file}" : "{email} užklausė slaptažodžio, kad gautų prieigą prie {file}",
-    "Someone requested the password to access {file}" : "Kažkas užklausė slaptažodį, kad gautų prieigą prie {file}",
-    "Unnamed conversation" : "Pokalbis be pavadinimo",
-    "This call is password-protected" : "Šis skambutis yra apsaugotas slaptažodžiu",
-    "Enter name for a new conversation" : "Įveskite naujo pokalbio pavadinimą",
-    "Room name can not be empty" : "Kambario pavadinimas negali būti tuščias",
-    "Calls are disabled in this conversation." : "Šiame pokalbyje skambinti negalima.",
-    "Error occurred while renaming the room" : "Klaida pervadinant kambarį",
-    "You can not send messages, because the conversation is locked." : "Negalite siųsti žinučių, nes pokalbis užrakintas.",
-    "The conversation is locked." : "Pokalbis užrakintas.",
-    "* You can now notify all participants by posting \"@all\" into the chat" : "* Galite siųsti pranešimą visiems dalyviams, pokalbyje parašę \"@all\"",
-    "Only moderators can enter the conversation when the lobby is enabled" : "Įjungus laukimo salę, į pokalbį galės užeiti tik moderatoriai",
-    "Error occurred while renaming the conversation" : "Klaida pervadinant pokalbį",
-    "Error occurred while changing lobby state" : "Klaida keičiant laukimo salės būseną",
-    "Invalid start time format" : "Neteisingas pradžios laiko formatas",
-    "Error occurred while setting the lobby start time" : "Klaida nustatant laukimo salės pradžios laiką"
+    "- Conversations can now have a lobby. This will allow moderators to join the chat and call already to prepare the meeting, while users and guests have to wait." : "- Dabar, pokalbiuose yra laukimo salė. Tai leis moderatoriams prisijungti prie pokalbio ir skambinti, kad paruoštų susitikimą, kol tuo tarpu kiti naudotojai ir svečiai turės laukti.",
+    "{email} tried to requested the password to access {file}" : "{email} bandė paprašyti slaptažodžio, kad gautų prieigą prie {file}",
+    "Someone tried to requested the password to access {file}" : "Kažkas bandė paprašyti slaptažodžio, kad gautų prieigą prie {file}",
+    "Start calls" : "Pradeda skambučius",
+    "Who can start a call?" : "Kas gali pradėti skambutį?",
+    "Join conversations at any time, any where, on any device." : "Prisijunkite prie pokalbių bet kur, bet kada, bet kokiame įrenginyje.",
+    "Loading contacts" : "Įkeliami adresatai",
+    "Contacts loading" : "Įkeliami adresatai"
 },
 "nplurals=4; plural=(n % 10 == 1 && (n % 100 > 19 || n % 100 < 11) ? 0 : (n % 10 >= 2 && n % 10 <=9) && (n % 100 > 19 || n % 100 < 11) ? 1 : n % 1 != 0 ? 2: 3);");
