@@ -3,31 +3,31 @@ OC.L10N.register(
     {
     "User" : "User",
     "Users" : "Pengguna",
+    "Name" : "Nama",
     "Remove from favorites" : "Remove from favorites",
     "Add to favorites" : "Add to favorites",
     "Contacts" : "Hubungi ",
-    "Groups" : "Kumpulan",
     "Loading" : "Loading",
+    "Groups" : "Kumpulan",
     "Error" : "Ralat",
     "Back" : "Kembali",
     "Close" : "Tutup",
     "Today" : "Hari ini",
     "Yesterday" : "Semalam",
+    "Settings" : "Tetapan",
+    "Edit" : "Sunting",
     "Share link" : "Share link",
     "Password protection" : "Password protection",
     "Enter a password" : "Enter a password",
-    "Edit" : "Sunting",
-    "Name" : "Nama",
     "Password" : "Kata laluan",
-    "Cancel" : "Batal",
     "Copied!" : "Disalin!",
     "Not supported!" : "Tidak menyokong!",
     "Press ⌘-C to copy." : "Tekan ⌘-C untuk menyalin.",
     "Press Ctrl-C to copy." : "Tekan Ctrl-C untuk menyalin.",
-    "Share" : "Kongsi",
+    "Cancel" : "Batal",
     "Change password" : "Ubah kata laluan",
     "Rename" : "Namakan",
     "Send" : "Hantar",
-    ", " : ","
+    "Share" : "Kongsi"
 },
 "nplurals=1; plural=0;");
