@@ -5,37 +5,38 @@ OC.L10N.register(
     "None" : "Ingen",
     "User" : "Bruker",
     "Users" : "Brukarare",
+    "Name" : "Namn",
+    "Saved" : "Lagra",
     "Favorite" : "Favoritt",
     "Remove from favorites" : "Remove from favorites",
     "Add to favorites" : "Add to favorites",
     "Contacts" : "Kontaktar",
-    "Groups" : "Grupper",
     "Loading" : "Loading",
+    "Groups" : "Grupper",
     "Error" : "Feil",
     "Password protect" : "Vern med passord",
     "Back" : "Tilbake",
     "Close" : "Lukk",
     "Today" : "I dag",
     "Yesterday" : "i går",
+    "Chat" : "Lynmelding",
+    "Settings" : "Instillingar",
+    "Edit" : "Endra",
+    "Dismiss" : "Forkast",
     "Share link" : "Del lenkje",
     "Password protection" : "Password protection",
     "Enter a password" : "Skriv inn eit passord",
-    "Chat" : "Lynmelding",
-    "Edit" : "Endra",
-    "Name" : "Namn",
-    "Saved" : "Lagra",
-    "Password" : "Passord",
-    "Cancel" : "Avbryt",
     "The password is wrong. Try again." : "Passordet er gale. Prøv igjen.",
+    "Password" : "Passord",
     "Copied!" : "Kopiert!",
     "Not supported!" : "Ikkje støtta!",
     "Press ⌘-C to copy." : "Trykk  ⌘-C for å kopiere.",
     "Press Ctrl-C to copy." : "Trykk Ctrl-C for å kopiere.",
-    "Share" : "Del",
+    "Cancel" : "Avbryt",
     "Change password" : "Endra passord",
     "Rename" : "Gje nytt namn",
     "Send" : "Send",
-    "Error while sharing" : "Feil ved deling",
-    ", " : ", "
+    "Share" : "Del",
+    "Error while sharing" : "Feil ved deling"
 },
 "nplurals=2; plural=(n != 1);");
