@@ -2,6 +2,7 @@ OC.L10N.register(
     "spreed",
     {
     "Users" : "کارنان",
+    "Name" : "نوم",
     "Copy link" : "لېنک کاپي کول",
     "Favorite" : "په نښه شوی",
     "Remove from favorites" : "له نښو ويستل",
@@ -12,20 +13,19 @@ OC.L10N.register(
     "Close" : "بندول",
     "Today" : "نن",
     "Yesterday" : "پرون",
+    "Settings" : "سمونې",
     "Share link" : "د شرېکېدو لېنک",
-    "Name" : "نوم",
     "Password" : "پاسورډ",
-    "Cancel" : "پرېښول",
     "Copy" : "کاپي کول",
     "Copied!" : "کاپي شو!",
     "Not supported!" : "د کار نه کېږي",
     "Press ⌘-C to copy." : "د کاپي لپاره د ⌘-C تڼۍ کېکاږئ.",
     "Press Ctrl-C to copy." : "د کاپي لپاره د Ctrl-C تڼۍ کېکاږئ.",
-    "Share" : "شریکول",
+    "Cancel" : "پرېښول",
     "Rename" : "نوم بدلول",
     "Send" : "لېږل",
+    "Share" : "شریکول",
     "Error while sharing" : "شريکولو کې ستونزه",
-    "Favorited" : "په نښه شو",
-    ", " : ", "
+    "Favorited" : "په نښه شو"
 },
 "nplurals=2; plural=(n != 1);");
