@@ -1,35 +1,51 @@
 OC.L10N.register(
     "spreed",
     {
+    "a conversation" : "uma conversa",
     "(Duration %s)" : "(Duração %s)",
-    "You attended a call with {user1}" : "Esteve numa chamada com {utilizador1}",
-    "You attended a call with {user1} and {user2}" : "Esteve numa chamada com {utilizador1} e {utilizador2}",
-    "You attended a call with {user1}, {user2} and {user3}" : "Esteve numa chamada com {utilizador1}, {utilizador2} e {utilizador3}",
-    "You attended a call with {user1}, {user2}, {user3} and {user4}" : "Esteve numa chamada com {utilizador1}, {utilizador2}, {utilizador3} e {utilizador4}",
-    "You attended a call with {user1}, {user2}, {user3}, {user4} and {user5}" : "Esteve numa chamada com {utilizador1}, {utilizador2}, {utilizador3}, {utilizador4} e {utilizador5}",
-    "{actor} invited you to {call}" : "{actor} convidou-o para {chamada}",
+    "You attended a call with {user1}" : "Esteve numa chamada com {user1}",
+    "_%n guest_::_%n guests_" : ["%n convidado","%n convidados"],
+    "You attended a call with {user1} and {user2}" : "Esteve numa chamada com {user1} e {user2}",
+    "You attended a call with {user1}, {user2} and {user3}" : "Esteve numa chamada com {user1}, {user2} e {user3}",
+    "You attended a call with {user1}, {user2}, {user3} and {user4}" : "Esteve numa chamada com {user1}, {user2}, {user3} e {user4}",
+    "You attended a call with {user1}, {user2}, {user3}, {user4} and {user5}" : "Esteve numa chamada com {user1}, {user2}, {user3}, {user4} e {user5}",
+    "_%n other_::_%n others_" : ["%n outro","%n outros"],
+    "{actor} invited you to {call}" : "{actor} convidou-o para {call}",
+    "You were invited to a <strong>conversation</strong> or had a <strong>call</strong>" : "Foi convidado para uma <strong>conversa</strong> ou teve uma <strong>chamada</strong>",
     "Talk" : "Falar",
     "Guest" : "Convidado",
+    "Welcome to Nextcloud Talk!\nIn this conversation you will be informed about new features available in Nextcloud Talk." : "Bem-vindo ao Nextcloud Talk!\nNesta conversa será informado sobre novas funcionalidades disponíveis no Nextcloud Talk.",
+    "New in Talk 6" : "Novo em Talk 6",
+    "- Microsoft Edge and Safari can now be used to participate in audio and video calls" : "- O Microsoft Edge e o Safari podem, agora, ser utilizados para participar em chamadas áudio e vídeo.",
     "Talk to %s" : "Falar com %s",
     "Join call" : "Juntar-se à chamada",
-    "{user} wants to talk with you" : "{utilizador} quer falar consigo",
-    "A group call has started in {call}" : "Uma chamada de grupo começou em {chamada}",
+    "{user} wants to talk with you" : "{user} quer falar consigo",
+    "A group call has started in {call}" : "Uma chamada de grupo começou em {call}",
     "Invalid date, date format must be YYYY-MM-DD" : "Data inválida, o formato da data deve ser AAAA-MM-DD",
+    "Leave call" : "Sair da chamada",
+    "Limit to groups" : "Limitado a grupos",
+    "Everyone" : "Para todos",
+    "Save changes" : "Guardar alterações",
+    "Saved!" : "Gravado!",
     "None" : "Nenhum",
     "User" : "Utilizador",
-    "Everyone" : "Para todos",
     "Disabled" : "Desactivado",
     "Users" : "Utilizadores",
+    "Name" : "Nome",
     "Validate SSL certificate" : "Validar certificado SSL",
+    "Saved" : "Gravado",
+    "Shared secret" : "Segredo partilhado",
     "TURN server protocols" : "Protocolos do servidor TURN",
     "UDP and TCP" : "UDP e TCP",
     "UDP only" : "Só UDP",
     "TCP only" : "Só TCP",
     "Copy link" : "Copiar ligação",
-    "No other people in this call" : "Sem mais pessoas nesta chamada",
     "Waiting for others to join the call …" : "À espera que outros se juntem à chamada ..",
     "You can invite others in the participant tab of the sidebar" : "Pode convidar outros no separador participantes na barra lateral  ",
     "Share this link to invite others!" : "Envie este link para convidar outros!",
+    "Mute audio" : "Silenciar áudio",
+    "Disable video" : "desactivar vídeo",
+    "Enable video" : "activar vídeo",
     "Screensharing options" : "Opções de partilha de ecrã",
     "Enable screensharing" : "Activar partilha de ecrã",
     "Screensharing requires the page to be loaded through HTTPS." : "A partilha de ecrã requer que a página seja carregada através de HTTPS.",
@@ -39,8 +55,6 @@ OC.L10N.register(
     "An error occurred while starting screensharing." : "Ocorreu um erro enquanto iniciava a partilha de ecrã.",
     "Your screen" : "O seu ecrã",
     "Show screen" : "Mostrar ecrã",
-    "Disable video" : "desactivar vídeo",
-    "Enable video" : "activar vídeo",
     "Favorite" : "Favorito",
     "Leave conversation" : "Sair da conversação",
     "Delete conversation" : "Eliminar conversação",
@@ -48,19 +62,19 @@ OC.L10N.register(
     "Add to favorites" : "Adicionar aos favoritos",
     "Conversations" : "Conversações",
     "Contacts" : "Contactos",
+    "Loading" : "A carregar",
     "Groups" : "Grupos",
     "Circles" : "Círculos",
-    "Loading" : "A carregar",
     "Error" : "Erro",
     "Password protect" : "Proteger com palavra-passe",
     "Back" : "Anterior",
     "Close" : "Fechar",
     "Conversation name" : "Nome da conversação",
     "Reply" : "Resposta",
-    "[Unknown user name]" : "[Nome de utilizador desconhecido]",
     "Today" : "Hoje",
     "Yesterday" : "Ontem",
     "{relativeDate}, {absoluteDate}" : "{relativeDate}, {absoluteDate}",
+    "Send message" : "Enviar mensagem",
     "moderator" : "moderador",
     "guest" : "convidado",
     "Demote from moderator" : "Relegar de moderador",
@@ -68,69 +82,58 @@ OC.L10N.register(
     "Remove participant" : "Remover participante",
     "No results" : "Sem resultados",
     "Participants" : "Participantes",
+    "Chat" : "Conversa",
+    "Settings" : "Definições",
+    "Edit" : "Editar",
+    "Dismiss" : "Dispensar",
     "Rename conversation" : "Renomear conversação",
-    "Guests" : "Convidados",
     "Share link" : "Partilhar ligação",
     "Password protection" : "Protegido por palavra-passe",
     "Enter a password" : "Insira uma palavra-passe",
-    "Chat" : "Conversa",
-    "Edit" : "Editar",
-    "Leave call" : "Sair da chamada",
-    "Limit to groups" : "Limitado a grupos",
-    "Limit app usage to groups." : "Limitar o uso da aplicação a grupos.",
-    "Save changes" : "Guardar alterações",
-    "Saved!" : "Gravado!",
-    "Name" : "Nome",
-    "Saved" : "Gravado",
-    "Shared secret" : "Segredo partilhado",
-    "Please enter the password for this call" : "Por favor introduza a palavra-passe para esta chamada",
-    "Password required" : "Necessário palavra-passe",
-    "Password" : "Palavra-passe",
-    "Cancel" : "Cancelar",
-    "Submit" : "Submeter",
+    "Grid view" : "Vista em grelha",
     "Access to microphone & camera is only possible with HTTPS" : "Só é possível aceder ao microfone & câmera com HTTPS",
     "Access to microphone & camera was denied" : "Acesso recusado ao microfone & câmera",
     "WebRTC is not supported in your browser" : "WebRTC não é suportado pelo seu browser",
     "Please use a different browser like Firefox or Chrome" : "Por favor use um browser diferente como Firefox ou Chrome",
     "Error while accessing microphone & camera" : "Erro a aceder ao microfone & câmera",
     "The password is wrong. Try again." : "A palavra-passe está errada. Por favor, tente de novo.",
+    "Password" : "Palavra-passe",
     "Android app" : "Aplicação Android",
     "iOS app" : "Aplicação iOS",
-    "Delete server" : "Apagar servidor",
-    "Add new server" : "Adicionar novo servidor",
-    "New public conversation" : "Nova conversação pública",
     "Copy" : "Copiar",
     "Copied!" : "Copiado!",
     "Not supported!" : "Não suportado!",
     "Press ⌘-C to copy." : "Pressionar ⌘-C para copiar.",
     "Press Ctrl-C to copy." : "Pressionar Ctrl-C para copiar.",
-    "Start a conversation" : "Iniciar uma conversação",
-    "Share" : "Partilhar",
+    "Please enter the password for this call" : "Por favor introduza a palavra-passe para esta chamada",
+    "Password required" : "Necessário palavra-passe",
+    "Cancel" : "Cancelar",
+    "Submit" : "Submeter",
+    "Guests" : "Convidados",
     "Change password" : "Alterar palavra-passe",
     "Set password" : "Definir palavra-passe",
     "Rename" : "Renomear",
+    "Link copied!" : "Ligação copiada!",
     "Conversation with {name}" : "Conversa com {name}",
     "Error occurred while setting password" : "Ocorreu um erro a definir a palavra-passe",
-    "Link copied!" : "Ligação copiada!",
     "You" : "Você",
     "No messages yet, start the conversation!" : "Ainda não tem mensagens, comece a conversa!",
     "New message …" : "Nova mensagem...",
     "Send" : "Enviar",
+    "Share" : "Partilhar",
+    "[Unknown user name]" : "[Nome de utilizador desconhecido]",
     "Error occurred while sending message" : "Ocorreu um erro a enviar a mensagem",
     "Error while sharing" : "Erro ao partilhar",
-    "Waiting for {participantName} to join the call …" : "À espera que {nomeDoParticipante} se junte à chamada ..",
+    "No other people in this call" : "Sem mais pessoas nesta chamada",
+    "Waiting for {participantName} to join the call …" : "À espera que {participantName} se junte à chamada ..",
     "WebRTC is not supported in your browser :-/" : "WebRTC não é suportado pelo seu browser :-/",
     "Waiting for camera and microphone permissions" : "À espera de permissões de câmera e microfone",
     "Please, give your browser access to use your camera and microphone in order to use this app." : "Por favor, permite ao seu browser aceder à sua câmera e microfone para que possa utilizar esta aplicação.",
-    "Mute audio" : "Silenciar áudio",
     "No Camera" : "Sem Câmera",
     "Screensharing is not supported by your browser." : "O seu browser não suporta partilha de ecrã",
     "Favorited" : "Nos Favoritos",
-    "Always notify" : "Notificar sempre",
-    "Never notify" : "Nunca notificar",
-    "{participantName}'s screen" : "Ecrã de {nomeDeParticipante}",
+    "{participantName}'s screen" : "Ecrã de {participantName}",
     "Guest's screen" : "Ecrã do convidado",
-    "You were invited to a <strong>talk</strong> room or had a <strong>call</strong>" : "Foi convidado para uma sala de <strong>conversa</strong> ou recebeu uma <strong>chamada</strong>",
-    ", " : ","
+    "Limit app usage to groups." : "Limitar o uso da aplicação a grupos."
 },
 "nplurals=2; plural=(n != 1);");
