@@ -4,30 +4,30 @@ OC.L10N.register(
     "None" : "කිසිවක් නැත",
     "User" : "User",
     "Users" : "පරිශීලකයන්",
+    "Name" : "නම",
     "Remove from favorites" : "Remove from favorites",
     "Add to favorites" : "Add to favorites",
     "Contacts" : "සබඳතා",
-    "Groups" : "කණ්ඩායම්",
     "Loading" : "Loading",
+    "Groups" : "කණ්ඩායම්",
     "Error" : "දෝෂයක්",
     "Password protect" : "මුර පදයකින් ආරක්ශාකරන්න",
     "Close" : "වසන්න",
     "Today" : "අද",
     "Yesterday" : "ඊයේ",
+    "Settings" : "සැකසුම්",
+    "Edit" : "සකසන්න",
     "Share link" : "Share link",
     "Password protection" : "Password protection",
     "Enter a password" : "Enter a password",
-    "Edit" : "සකසන්න",
-    "Name" : "නම",
     "Password" : "මුර පදය",
-    "Cancel" : "අවලංගු කරන්න",
     "Copied!" : "පිටපත් කරා",
     "Not supported!" : "සහාය දක්වන්නේ නැත.",
     "Press ⌘-C to copy." : "පිටපත් කිරීම සදහා Ctrl + C ඔබන්න.",
     "Press Ctrl-C to copy." : "පිටපත් කිරීම සදහා Ctrl + C ඔබන්න.",
-    "Share" : "බෙදා හදා ගන්න",
+    "Cancel" : "අවලංගු කරන්න",
     "Change password" : "මුරපදය වෙනස් කිරීම",
     "Rename" : "නැවත නම් කරන්න",
-    ", " : ", "
+    "Share" : "බෙදා හදා ගන්න"
 },
 "nplurals=2; plural=(n != 1);");
