@@ -4,26 +4,27 @@ OC.L10N.register(
     "None" : "يوق",
     "User" : "User",
     "Users" : "ئىشلەتكۈچىلەر",
+    "Name" : "ئاتى",
     "Favorite" : "يىغقۇچ",
     "Remove from favorites" : "Remove from favorites",
     "Add to favorites" : "Add to favorites",
     "Contacts" : "ئالاقەداشلار",
-    "Groups" : "گۇرۇپپا",
     "Loading" : "Loading",
+    "Groups" : "گۇرۇپپا",
     "Error" : "خاتالىق",
     "Close" : "ياپ",
     "Reply" : "جاۋاب قايتۇر",
     "Today" : "بۈگۈن",
+    "Settings" : "تەڭشەكلەر",
+    "Edit" : "تەھرىر",
     "Share link" : "Share link",
     "Password protection" : "Password protection",
     "Enter a password" : "Enter a password",
-    "Edit" : "تەھرىر",
-    "Name" : "ئاتى",
     "Password" : "ئىم",
     "Cancel" : "ۋاز كەچ",
-    "Share" : "ھەمبەھىر",
     "Change password" : "ئىم ئۆزگەرت",
     "Rename" : "ئات ئۆزگەرت",
-    "Send" : "يوللا"
+    "Send" : "يوللا",
+    "Share" : "ھەمبەھىر"
 },
 "nplurals=1; plural=0;");
