@@ -62,23 +62,31 @@ OC.L10N.register(
     "Invalid date, date format must be YYYY-MM-DD" : "Định dạng ngày không hợp lệ phải là YYYY-MM-DD",
     "Conversation not found" : "Không tìm thấy cuộc hội thoại",
     "Path is already shared with this room" : "Đường dẫn đã được chia sẻ với phòng này",
+    "Leave call" : "Rời khỏi cuộc gọi",
     "Request password" : "Yêu cầu mật khẩu",
     "Error requesting the password." : "Lỗi khi đang yêu cầu mật khẩu.",
     "This conversation has ended" : "Cuộc trò chuyện này đã kết thúc",
+    "Limit to groups" : "Giới hạn nhóm",
+    "Everyone" : "Tất cả mọi người",
+    "Save changes" : "Lưu thay đổi",
     "None" : "Không có",
     "User" : "Người dùng",
-    "Everyone" : "Tất cả mọi người",
     "Disabled" : "Tắt",
     "Users" : "Người dùng",
-    "TURN server URL" : "URL máy chủ TURN",
+    "Name" : "Tên",
+    "Signaling server URL" : "URL máy chủ đăng ký",
     "Validate SSL certificate" : "Xác thực chứng chỉ SSL",
+    "Saved" : "Đã lưu",
+    "Shared secret" : "Chia sẽ mật khẩu",
     "STUN server URL" : "URL máy chủ STUN",
+    "STUN servers" : "Máy chủ STUN",
+    "A STUN server is used to determine the public IP address of participants behind a router." : "Máy chủ STUN được sử dụng để xác định địa chỉ IP công khai của người tham gia phía sau bộ định tuyến.",
+    "TURN server URL" : "URL máy chủ TURN",
     "TURN server protocols" : "Giao thức máy chủ TURN",
     "UDP and TCP" : "UDP và TCP",
     "UDP only" : "Chỉ UDP",
     "TCP only" : "Chỉ TCP",
     "Copy link" : "Sao chép liên kết",
-    "No other people in this call" : "Không có người nào trong cuộc gọi này",
     "Waiting for others to join the call …" : "Đang chờ người khác tham gia cuộc gọi…",
     "You can invite others in the participant tab of the sidebar" : "Bạn có thể mời những người khác trong tab người tham gia của thanh bên",
     "You can invite others in the participant tab of the sidebar or share this link to invite others!" : "Bạn có thể mời những người khác trong tab người tham gia của thanh bên hoặc chia sẻ liên kết này để mời những người khác!",
@@ -88,8 +96,11 @@ OC.L10N.register(
     "No audio" : "Không có âm thanh",
     "Mute audio (m)" : "Tắt âm thành (m)",
     "Unmute audio (m)" : "Mở âm thanh (m)",
+    "Mute audio" : "Tắt âm thanh",
     "Disable video (v)" : "Tắt Video (v)",
     "Enable video (v)" : "Bật Video (v)",
+    "Disable video" : "Tắt Video",
+    "Enable video" : "Bật Video",
     "Screensharing options" : "Tùy chọn chia sẻ màn hình",
     "Enable screensharing" : "Bật chia sẽ màn hình",
     "Screensharing requires the page to be loaded through HTTPS." : "Chia sẻ màn hình yêu cầu trang phải tải qua HTTPS.",
@@ -99,8 +110,6 @@ OC.L10N.register(
     "An error occurred while starting screensharing." : "Đã xảy ra lỗi khi bắt đầu chia sẻ màn hình.",
     "Your screen" : "Màn hình của bạn",
     "Show screen" : "Hiện màn hình",
-    "Disable video" : "Tắt Video",
-    "Enable video" : "Bật Video",
     "Favorite" : "Ưa thích",
     "Leave conversation" : "Rời khỏi cuộc đàm thoại",
     "Delete conversation" : "Xóa đàm thoại",
@@ -108,19 +117,19 @@ OC.L10N.register(
     "Add to favorites" : "Thêm vào ưa thích",
     "Conversations" : "Đàm thoại",
     "Contacts" : "Liên hệ",
+    "Loading" : "Đang tải",
     "Groups" : "Nhóm",
     "Circles" : "Vòng kết nối",
-    "Loading" : "Đang tải",
     "Error" : "Lỗi",
     "Password protect" : "Mật khẩu bảo vệ",
     "Back" : "Quay lại",
     "Close" : "Đóng",
     "Conversation name" : "Tên đàm thoại",
     "Reply" : "Trả l",
-    "[Unknown user name]" : "[Tên người dùng chưa biết]",
     "Today" : "Hôm nay",
     "Yesterday" : "Hôm qua",
     "{relativeDate}, {absoluteDate}" : "{relativeDate}, {absoluteDate}",
+    "Send message" : "Gửi thông điệp",
     "File to share" : "Tệp để chia sẻ",
     "moderator" : "Người kiểm duyệt",
     "Demote from moderator" : "Hạ uy tín từ người kiểm duyệt",
@@ -128,27 +137,19 @@ OC.L10N.register(
     "Remove participant" : "Xóa người tham gia",
     "No results" : "Không có kết quả",
     "Participants" : "Người tham gia",
+    "Chat" : "Trò chuyện",
+    "Projects" : "Dự án",
+    "Settings" : "Thiết lập",
+    "Edit" : "Chỉnh sửa",
+    "Start call" : "Bắt đầu cuộc gọi",
+    "Dismiss" : "Bỏ qua",
     "Rename conversation" : "Đổi tên cuộc đàm thoại",
     "Share link" : "Chia sẽ liên kết",
     "Password protection" : "Password protection",
     "Enter a password" : "Nhập mật khẩu",
-    "Chat" : "Trò chuyện",
-    "Edit" : "Chỉnh sửa",
-    "Leave call" : "Rời khỏi cuộc gọi",
-    "Start call" : "Bắt đầu cuộc gọi",
-    "Limit to groups" : "Giới hạn nhóm",
-    "Save changes" : "Lưu thay đổi",
-    "Name" : "Tên",
-    "Saved" : "Đã lưu",
-    "Shared secret" : "Chia sẽ mật khẩu",
-    "STUN servers" : "Máy chủ STUN",
-    "A STUN server is used to determine the public IP address of participants behind a router." : "Máy chủ STUN được sử dụng để xác định địa chỉ IP công khai của người tham gia phía sau bộ định tuyến.",
+    "Exit fullscreen (f)" : "Thoát chế độ toàn màn hình (f)",
+    "Fullscreen (f)" : "Toàn màn hình (f)",
     "Join a conversation or start a new one" : "Tham gia cuộc trò chuyện hoặc bắt đầu một cuộc trò chuyện mới",
-    "Please enter the password for this call" : "Hãy nhập một mật khẩu cho cuộc gọi này",
-    "Password required" : "Mật khẩu đã được yêu cầu",
-    "Password" : "Mật khẩu",
-    "Cancel" : "Hủy bỏ",
-    "Submit" : "Gửi đi",
     "Access to microphone & camera is only possible with HTTPS" : "Chỉ có thể truy cập micrô và máy ảnh bằng HTTPS",
     "Please move your setup to HTTPS" : "Vui lòng di chuyển thiết lập của bạn sang HTTPS",
     "Access to microphone & camera was denied" : "Quyền truy cập vào micrô và máy ảnh đã bị từ chối",
@@ -156,48 +157,44 @@ OC.L10N.register(
     "Please use a different browser like Firefox or Chrome" : "Vui lòng sử dụng một trình duyệt khác như Firefox hoặc Chrome",
     "Error while accessing microphone & camera" : "Lỗi khi truy cập micrô và máy ảnh",
     "The password is wrong. Try again." : "Sai mật khẩu. Thử lại.",
-    "An external signaling server can optionally be used for larger installations. Leave empty to use the internal signaling server." : "Một máy chủ báo hiệu bên ngoài có thể được sử dụng tùy chọn cho các cài đặt lớn hơn. Để trống để sử dụng máy chủ báo hiệu nội bộ.",
+    "Password" : "Mật khẩu",
     "TURN server" : "Máy chủ TURN",
     "The TURN server is used to proxy the traffic from participants behind a firewall." : "Máy chủ TURN được sử dụng để ủy quyền lưu lượng truy cập từ những người tham gia đằng sau tường lửa.",
+    "An external signaling server can optionally be used for larger installations. Leave empty to use the internal signaling server." : "Một máy chủ báo hiệu bên ngoài có thể được sử dụng tùy chọn cho các cài đặt lớn hơn. Để trống để sử dụng máy chủ báo hiệu nội bộ.",
     "%s Talk on your mobile devices" : "%sNói chuyện trên thiết bị di động của bạn ",
     "Android app" : "Ứng dụng Android",
     "iOS app" : "Ứng dụng IOS",
-    "Signaling server URL" : "URL máy chủ đăng ký",
-    "Delete server" : "Xóa máy chủ",
-    "Add new server" : "Thêm máy chủ mới",
-    "You deleted all STUN servers. As it is almost always needed, a default STUN server was added." : "Bạn đã xóa tất cả các máy chủ STUN. Vì nó gần như luôn luôn cần thiết, một máy chủ STUN mặc định đã được thêm vào.",
-    "TURN server shared secret" : "Khóa đã được chia sẽ máy chủ TURN",
-    "New public conversation" : "Tạo đàm thoại công khai mới",
-    "New group conversation" : "Tạo nhóm đàm thoại mới",
     "{name} (public)" : "{name} (public)",
     "New conversation …" : "Đàm thoại mới...",
-    "Exit fullscreen (f)" : "Thoát chế độ toàn màn hình (f)",
-    "Fullscreen (f)" : "Toàn màn hình (f)",
-    "Set your name in the chat window so other participants can identify you better." : "Đặt tên của bạn trong cửa sổ trò chuyện để những người tham gia khác có thể xác định bạn tốt hơn.",
     "Copy" : "Sao chép",
     "Copied!" : "Đã sao chép!",
     "Not supported!" : "Không hỗ trợ!",
     "Press ⌘-C to copy." : "Bấm ⌘-C để sao chép.",
     "Press Ctrl-C to copy." : "Bấm Ctrl-C để sao chép.",
-    "Start a conversation" : "Bắt đầu một cuộc Đàm thoại",
-    "Share" : "Chia sẻ",
+    "Please enter the password for this call" : "Hãy nhập một mật khẩu cho cuộc gọi này",
+    "Password required" : "Mật khẩu đã được yêu cầu",
+    "Cancel" : "Hủy bỏ",
+    "Submit" : "Gửi đi",
     "Change password" : "Đổi mật khẩu",
     "Set password" : "Đặt mật khẩu",
     "Rename" : "Đổi tên",
+    "Link copied!" : "Liên kết đã được sao chép!",
     "Conversation with {name}" : "Đàm thoại với {name}",
     "Error occurred while setting password" : "Đã xảy ra lỗi khi đặt mật khẩu",
-    "Link copied!" : "Liên kết đã được sao chép!",
     "You" : "Bạn",
     "No messages yet, start the conversation!" : "Chưa có tin nhắn, bắt đầu cuộc trò chuyện!",
     "New message …" : "Thông điệp mới...",
     "Send" : "Gửi",
+    "Share" : "Chia sẻ",
+    "[Unknown user name]" : "[Tên người dùng chưa biết]",
     "Error occurred while sending message" : "Đã xảy ra lỗi khi gửi tin nhắn",
     "Error while sharing" : "Lỗi khi chia sẻ",
+    "No other people in this call" : "Không có người nào trong cuộc gọi này",
     "Waiting for {participantName} to join the call …" : "Đang chờ {participantName} tham gia cuộc gọi…",
     "WebRTC is not supported in your browser :-/" : "WebRTC không được hỗ trợ trong trình duyệt của bạn :-/",
     "Waiting for camera and microphone permissions" : "Đang chờ cấp quyền đối với máy ảnh và micrô",
     "Please, give your browser access to use your camera and microphone in order to use this app." : "Vui lòng cung cấp cho trình duyệt quyền truy cập của bạn để sử dụng máy ảnh và micrô của bạn để sử dụng ứng dụng này.",
-    "Mute audio" : "Tắt âm thanh",
+    "Set your name in the chat window so other participants can identify you better." : "Đặt tên của bạn trong cửa sổ trò chuyện để những người tham gia khác có thể xác định bạn tốt hơn.",
     "Share screen" : "Chia sẽ màn hình",
     "No Camera" : "Không có Camera",
     "Screensharing is not supported by your browser." : "Chia sẽ màn hình không được hỗ trợ bởi trình duyệt của bạn.",
@@ -205,17 +202,6 @@ OC.L10N.register(
     "Favorited" : "Được ưa thích",
     "{participantName}'s screen" : "Màn hình của {participantName}",
     "Guest's screen" : "Màn hình Khách",
-    "You were invited to a <strong>talk</strong> room or had a <strong>call</strong>" : "Bạn đã được mời đến một <strong>phòng trò chuyện</strong> hoặc có một <strong>cuộc gọi</strong>",
-    "_%n other guest_::_%n other guests_" : ["%nnhững khách khác "],
-    ", " : ",",
-    "%s invited you to a private conversation" : "%sđã mời bạn tham gia cuộc trò chuyện riêng ",
-    "%s invited you to a group conversation: %s" : "%sđã mời bạn tham gia cuộc trò chuyện nhóm: %s ",
-    "%s invited you to a group conversation" : "%s đã mời bạn tham gia cuộc trò chuyện nhóm",
-    "{user} invited you to a group conversation" : "{user} đã mời bạn tham gia cuộc trò chuyện nhóm",
-    "A group call has started" : "Một cuộc gọi nhóm đã được thực hiện",
-    "Video & audio-conferencing using WebRTC" : "Video & hội nghị âm thanh bằng WebRTC",
-    "This call is password-protected" : "Cuộc gọi này được bảo vệ bằng mật khẩu",
-    "Signaling server" : "Máy chủ đăng ký",
     "Join conversations at any time, any where, on any device." : "Tham gia cuộc trò chuyện bất kỳ lúc nào, ở bất kỳ đâu, trên mọi thiết bị."
 },
 "nplurals=1; plural=0;");
