@@ -1,17 +1,19 @@
 OC.L10N.register(
     "spreed",
     {
+    "Everyone" : "所有人",
     "None" : "空",
     "User" : "User",
-    "Everyone" : "所有人",
     "Disabled" : "停用",
     "Users" : "用戶",
+    "Name" : "名稱",
+    "Saved" : "已儲存",
     "Copy link" : "複製連結",
     "Remove from favorites" : "Remove from favorites",
     "Add to favorites" : "Add to favorites",
     "Contacts" : "聯絡人",
-    "Groups" : "群組",
     "Loading" : "Loading",
+    "Groups" : "群組",
     "Error" : "錯誤",
     "Password protect" : "密碼保護",
     "Back" : "返回",
@@ -19,25 +21,23 @@ OC.L10N.register(
     "Reply" : "回覆",
     "Today" : "今日",
     "Yesterday" : "明日",
+    "Settings" : "設定",
+    "Edit" : "編輯",
     "Share link" : "分享連結",
     "Password protection" : "Password protection",
     "Enter a password" : "Enter a password",
-    "Edit" : "編輯",
-    "Name" : "名稱",
-    "Saved" : "已儲存",
     "Password" : "密碼",
-    "Cancel" : "取消",
     "Android app" : "Android 應用程式",
     "iOS app" : "iOS 應用程式",
     "Copied!" : "已複製!",
     "Not supported!" : "不支援!",
     "Press ⌘-C to copy." : "按下 ⌘-C 複製",
     "Press Ctrl-C to copy." : "按下 Ctrl-C 複製",
-    "Share" : "分享",
+    "Cancel" : "取消",
     "Change password" : "更改密碼",
     "Rename" : "重新命名",
     "Send" : "發送",
-    "Error while sharing" : "分享時發生錯誤",
-    ", " : ","
+    "Share" : "分享",
+    "Error while sharing" : "分享時發生錯誤"
 },
 "nplurals=1; plural=0;");
