@@ -30,6 +30,9 @@ use OCP\Security\ISecureRandom;
 
 class Config {
 
+	public const SIGNALING_INTERNAL = 'internal';
+	public const SIGNALING_EXTERNAL = 'external';
+
 	/** @var IConfig */
 	protected $config;
 	/** @var ITimeFactory */
@@ -251,6 +254,13 @@ class Config {
 		);
 	}
 
+	public function getSignalingMode(): string {
+		if (empty($this->getSignalingServers())) {
+			return self::SIGNALING_INTERNAL;
+		}
+		return self::SIGNALING_EXTERNAL;
+	}
+
 	/**
 	 * Returns list of signaling servers. Each entry contains the URL of the
 	 * server and a flag whether the certificate should be verified.
