@@ -21,12 +21,12 @@ declare(strict_types=1);
  * along with this program.  If not, see <http://www.gnu.org/licenses/>.
  *
  */
-namespace OCA\Spreed\Migration;
+namespace OCA\Talk\Migration;
 
 use Doctrine\DBAL\Platforms\PostgreSqlPlatform;
 use Doctrine\DBAL\Types\Type;
-use OCA\Spreed\Participant;
-use OCA\Spreed\Room;
+use OCA\Talk\Participant;
+use OCA\Talk\Room;
 use OCP\DB\ISchemaWrapper;
 use OCP\DB\QueryBuilder\IQueryBuilder;
 use OCP\IConfig;
