@@ -22,7 +22,7 @@ declare(strict_types=1);
  *
  */
 
-namespace OCA\Spreed;
+namespace OCA\Talk;
 
 use OCP\DB\QueryBuilder\IQueryBuilder;
 use OCP\IConfig;
